syscalls = [
    [
        "NtAccessCheck",
        "NtWorkerFactoryWorkerReady",
        "NtAcceptConnectPort",
        "NtYieldExecution",
        "NtWriteVirtualMemory",
        "NtWriteRequestData",
        "NtWriteFileGather",
        "NtWriteFile",
        "NtSetHighEventPair",
        "NtSetHighEventPair",
        "NtWaitForWorkViaWorkerFactory",
        "NtWaitForSingleObject",
        "NtWaitForMultipleObjects32",
        "NtWaitForMultipleObjects",
        "NtWaitForKeyedEvent",
        "NtWaitForDebugEvent",
        "NtWaitForAlertByThreadId",
        "NtVdmControl",
        "NtUnsubscribeWnfStateChange",
        "NtUpdateWnfStateData",
        "NtUnmapViewOfSection",
        "NtUnmapViewOfSectionEx",
        "NtUnlockVirtualMemory",
        "NtUnlockFile",
        "NtUnloadKeyEx",
        "NtUnloadKey2",
        "NtUnloadKey",
        "NtUnloadDriver",
        "NtUmsThreadYield",
        "NtTranslateFilePath",
        "NtTraceEvent",
        "NtTraceControl",
        "NtThawTransactions",
        "NtThawRegistry",
        "NtTestAlert",
        "NtTerminateThread",
        "NtTerminateProcess",
        "NtTerminateJobObject",
        "NtSystemDebugControl",
        "NtSuspendThread",
        "NtSuspendProcess",
        "NtSubscribeWnfStateChange",
        "NtStopProfile",
        "NtStartProfile",
        "NtSinglePhaseReject",
        "NtSignalAndWaitForSingleObject",
        "NtShutdownWorkerFactory",
        "NtShutdownSystem",
        "NtSetWnfProcessNotificationEvent",
        "NtSetVolumeInformationFile",
        "NtSetValueKey",
        "NtSetUuidSeed",
        "NtSetTimerResolution",
        "NtSetTimerEx",
        "NtSetTimer",
        "NtSetThreadExecutionState",
        "NtSetSystemTime",
        "NtSetSystemPowerState",
        "NtSetSystemInformation",
        "NtSetSystemEnvironmentValueEx",
        "NtSetSystemEnvironmentValue",
        "NtSetSecurityObject",
        "NtSetQuotaInformationFile",
        "NtSetHighEventPair",
        "NtSetHighEventPair",
        "NtSetLdtEntries",
        "NtSetIRTimer",
        "NtSetTimer2",
        "NtCancelTimer2",
        "NtSetIoCompletionEx",
        "NtSetIoCompletion",
        "NtSetIntervalProfile",
        "NtSetInformationWorkerFactory",
        "NtSetInformationTransactionManager",
        "NtSetInformationTransaction",
        "NtSetInformationToken",
        "NtSetInformationThread",
        "NtSetInformationResourceManager",
        "NtSetInformationProcess",
        "NtSetInformationObject",
        "NtSetInformationKey",
        "NtSetInformationJobObject",
        "NtSetInformationFile",
        "NtSetInformationEnlistment",
        "NtSetInformationDebugObject",
        "NtSetHighEventPair",
        "NtSetHighEventPair",
        "NtSetEventBoostPriority",
        "NtSetEvent",
        "NtSetEaFile",
        "NtSetDriverEntryOrder",
        "NtSetDefaultUILanguage",
        "NtSetDefaultLocale",
        "NtSetDefaultHardErrorPort",
        "NtSetDebugFilterState",
        "NtSetContextThread",
        "NtSetCachedSigningLevel2",
        "NtSetCachedSigningLevel",
        "NtSetBootOptions",
        "NtSetBootEntryOrder",
        "NtSerializeBoot",
        "NtSecureConnectPort",
        "NtSaveMergedKeys",
        "NtSaveKeyEx",
        "NtSaveKey",
        "NtRollforwardTransactionManager",
        "NtRollbackTransaction",
        "NtRollbackEnlistment",
        "NtRollbackComplete",
        "NtRevertContainerImpersonation",
        "NtResumeThread",
        "NtResumeProcess",
        "NtRestoreKey",
        "NtResetWriteWatch",
        "NtResetEvent",
        "NtRequestWaitReplyPort",
        "NtRequestPort",
        "NtReplyWaitReplyPort",
        "NtReplyWaitReceivePortEx",
        "NtReplyWaitReceivePort",
        "NtReplyPort",
        "NtReplacePartitionUnit",
        "NtReplaceKey",
        "NtRenameTransactionManager",
        "NtRenameKey",
        "NtRemoveProcessDebug",
        "NtRemoveIoCompletionEx",
        "NtRemoveIoCompletion",
        "NtReleaseWorkerFactoryWorker",
        "NtReleaseSemaphore",
        "NtReleaseMutant",
        "NtReleaseKeyedEvent",
        "NtRegisterThreadTerminatePort",
        "NtRegisterProtocolAddressInformation",
        "NtRecoverTransactionManager",
        "NtRecoverResourceManager",
        "NtRecoverEnlistment",
        "NtReadVirtualMemory",
        "NtReadRequestData",
        "NtReadOnlyEnlistment",
        "NtReadFileScatter",
        "NtReadFile",
        "NtRaiseHardError",
        "NtRaiseException",
        "NtQueueApcThreadEx",
        "NtQueueApcThread",
        "NtQueryAuxiliaryCounterFrequency",
        "NtQueryWnfStateData",
        "NtQueryWnfStateNameInformation",
        "NtQueryVolumeInformationFile",
        "NtQueryVirtualMemory",
        "NtQueryValueKey",
        "NtQueryTimerResolution",
        "NtQueryTimer",
        "NtQuerySystemTime",
        "NtQuerySystemInformationEx",
        "NtQuerySystemInformation",
        "NtQuerySystemEnvironmentValueEx",
        "NtQuerySystemEnvironmentValue",
        "NtQuerySymbolicLinkObject",
        "NtQuerySemaphore",
        "NtQuerySecurityPolicy",
        "NtQuerySecurityObject",
        "NtQuerySecurityAttributesToken",
        "NtQuerySection",
        "NtQueryQuotaInformationFile",
        "NtQueryPortInformationProcess",
        "NtQueryPerformanceCounter",
        "NtQueryOpenSubKeysEx",
        "NtQueryOpenSubKeys",
        "NtQueryObject",
        "NtQueryMutant",
        "NtQueryMultipleValueKey",
        "NtQueryLicenseValue",
        "NtQueryKey",
        "NtQueryIoCompletion",
        "NtQueryIntervalProfile",
        "NtQueryInstallUILanguage",
        "NtQueryInformationWorkerFactory",
        "NtQueryInformationTransactionManager",
        "NtQueryInformationTransaction",
        "NtQueryInformationToken",
        "NtQueryInformationThread",
        "NtQueryInformationResourceManager",
        "NtQueryInformationProcess",
        "NtQueryInformationPort",
        "NtQueryInformationJobObject",
        "NtQueryInformationFile",
        "NtQueryInformationEnlistment",
        "NtQueryInformationByName",
        "NtQueryInformationAtom",
        "NtQueryFullAttributesFile",
        "NtQueryEvent",
        "NtQueryEaFile",
        "NtQueryDriverEntryOrder",
        "NtQueryDirectoryObject",
        "NtQueryDirectoryFile",
        "NtQueryDefaultUILanguage",
        "NtQueryDefaultLocale",
        "NtQueryDebugFilterState",
        "NtQueryBootOptions",
        "NtQueryBootEntryOrder",
        "NtQueryAttributesFile",
        "NtPulseEvent",
        "NtProtectVirtualMemory",
        "NtPropagationFailed",
        "NtPropagationComplete",
        "NtPrivilegeObjectAuditAlarm",
        "NtPrivilegedServiceAuditAlarm",
        "NtPrivilegeCheck",
        "NtSetInformationVirtualMemory",
        "NtPrePrepareEnlistment",
        "NtPrePrepareComplete",
        "NtPrepareEnlistment",
        "NtPrepareComplete",
        "NtPowerInformation",
        "NtPlugPlayControl",
        "NtOpenTransactionManager",
        "NtOpenTransaction",
        "NtOpenTimer",
        "NtOpenThreadTokenEx",
        "NtOpenThreadToken",
        "NtOpenThread",
        "NtOpenSymbolicLinkObject",
        "NtOpenSession",
        "NtOpenSemaphore",
        "NtOpenSection",
        "NtOpenResourceManager",
        "NtOpenPartition",
        "NtOpenProcessTokenEx",
        "NtOpenProcessToken",
        "NtOpenProcess",
        "NtOpenPrivateNamespace",
        "NtOpenObjectAuditAlarm",
        "NtOpenMutant",
        "NtOpenKeyTransactedEx",
        "NtOpenKeyTransacted",
        "NtOpenKeyEx",
        "NtOpenKeyedEvent",
        "NtOpenKey",
        "NtOpenJobObject",
        "NtOpenIoCompletion",
        "NtOpenFile",
        "NtCreateEventPair",
        "NtOpenEvent",
        "NtOpenEnlistment",
        "NtOpenDirectoryObject",
        "NtNotifyChangeSession",
        "NtNotifyChangeMultipleKeys",
        "NtNotifyChangeKey",
        "NtNotifyChangeDirectoryFile",
        "NtManagePartition",
        "NtModifyDriverEntry",
        "NtModifyBootEntry",
        "NtMapViewOfSection",
        "NtMapUserPhysicalPagesScatter",
        "NtMapUserPhysicalPages",
        "NtMapCMFModule",
        "NtMakeTemporaryObject",
        "NtMakePermanentObject",
        "NtLockVirtualMemory",
        "NtLockRegistryKey",
        "NtLockProductActivationKeys",
        "NtLockFile",
        "NtLoadKeyEx",
        "NtLoadKey2",
        "NtLoadKey",
        "NtLoadHotPatch",
        "NtLoadEnclaveData",
        "NtLoadDriver",
        "NtListenPort",
        "NtIsUILanguageComitted",
        "NtIsSystemResumeAutomatic",
        "NtIsProcessInJob",
        "NtInitiatePowerAction",
        "NtInitializeRegistry",
        "NtInitializeNlsFiles",
        "NtInitializeEnclave",
        "NtImpersonateThread",
        "NtImpersonateClientOfPort",
        "NtImpersonateAnonymousToken",
        "NtGetWriteWatch",
        "NtGetNotificationResourceManager",
        "NtGetNlsSectionPtr",
        "NtGetNextThread",
        "NtGetNextProcess",
        "NtGetMUIRegistryInfo",
        "NtGetDevicePowerState",
        "NtGetCurrentProcessorNumberEx",
        "NtGetCurrentProcessorNumber",
        "NtGetContextThread",
        "NtGetCompleteWnfStateSubscription",
        "NtGetCachedSigningLevel",
        "NtFsControlFile",
        "NtFreezeTransactions",
        "NtFreezeRegistry",
        "NtFreeVirtualMemory",
        "NtFreeUserPhysicalPages",
        "NtFlushWriteBuffer",
        "NtFlushVirtualMemory",
        "NtFlushProcessWriteBuffers",
        "NtFlushKey",
        "FsRtlSyncVolumes",
        "NtFlushInstallUILanguage",
        "NtFlushBuffersFile",
        "NtFlushBuffersFileEx",
        "NtFindAtom",
        "NtFilterToken",
        "NtFilterTokenEx",
        "NtFilterBootOption",
        "NtExtendSection",
        "NtEnumerateValueKey",
        "NtEnumerateTransactionObject",
        "NtEnumerateSystemEnvironmentValuesEx",
        "NtEnumerateKey",
        "NtEnumerateDriverEntries",
        "NtEnumerateBootEntries",
        "NtEnableLastKnownGood",
        "NtDuplicateToken",
        "NtDuplicateObject",
        "NtDrawText",
        "NtDisplayString",
        "NtDisableLastKnownGood",
        "NtDeviceIoControlFile",
        "NtDeleteWnfStateName",
        "NtDeleteWnfStateData",
        "NtDeleteValueKey",
        "NtDeletePrivateNamespace",
        "NtDeleteObjectAuditAlarm",
        "NtDeleteKey",
        "NtDeleteFile",
        "NtDeleteDriverEntry",
        "NtDeleteBootEntry",
        "NtDeleteAtom",
        "NtDelayExecution",
        "NtDebugContinue",
        "NtDebugActiveProcess",
        "NtCreatePartition",
        "NtCreateWorkerFactory",
        "NtCreateWnfStateName",
        "NtCreateWaitCompletionPacket",
        "NtCreateWaitablePort",
        "NtCreateUserProcess",
        "NtCreateTransactionManager",
        "NtCreateTransaction",
        "NtCreateToken",
        "NtCreateLowBoxToken",
        "NtCreateTokenEx",
        "NtCreateTimer",
        "NtCreateThreadEx",
        "NtCreateThread",
        "NtCreateSymbolicLinkObject",
        "NtCreateSemaphore",
        "NtCreateSection",
        "NtCreateResourceManager",
        "NtCreateProfileEx",
        "NtCreateProfile",
        "NtCreateProcessEx",
        "NtCreateProcess",
        "NtCreatePrivateNamespace",
        "NtCreatePort",
        "NtCreatePagingFile",
        "NtCreateNamedPipeFile",
        "NtCreateMutant",
        "NtCreateMailslotFile",
        "NtCreateKeyTransacted",
        "NtCreateKeyedEvent",
        "NtCreateKey",
        "NtCreateJobSet",
        "NtCreateJobObject",
        "NtCreateIRTimer",
        "NtCreateTimer2",
        "NtCreateIoCompletion",
        "NtCreateFile",
        "NtCreateEventPair",
        "NtCreateEvent",
        "NtCreateEnlistment",
        "NtCreateEnclave",
        "NtCreateDirectoryObjectEx",
        "NtCreateDirectoryObject",
        "NtCreateDebugObject",
        "NtConvertBetweenAuxiliaryCounterAndPerformanceCounter",
        "NtContinue",
        "NtConnectPort",
        "NtCompressKey",
        "NtCompleteConnectPort",
        "NtCompareTokens",
        "NtCompareSigningLevels",
        "NtCompareObjects",
        "NtCompactKeys",
        "NtCommitTransaction",
        "NtCommitEnlistment",
        "NtCommitComplete",
        "NtCloseObjectAuditAlarm",
        "NtClose",
        "NtClearEvent",
        "NtCancelWaitCompletionPacket",
        "NtCancelTimer",
        "NtCancelSynchronousIoFile",
        "NtCancelIoFileEx",
        "NtCancelIoFile",
        "NtCallbackReturn",
        "NtAssociateWaitCompletionPacket",
        "NtAssignProcessToJobObject",
        "NtAreMappedFilesTheSame",
        "NtApphelpCacheControl",
        "NtAlpcSetInformation",
        "NtAlpcSendWaitReceivePort",
        "NtAlpcRevokeSecurityContext",
        "NtAlpcQueryInformationMessage",
        "NtAlpcQueryInformation",
        "NtAlpcOpenSenderThread",
        "NtAlpcOpenSenderProcess",
        "NtAlpcImpersonateClientOfPort",
        "NtAlpcImpersonateClientContainerOfPort",
        "NtAlpcDisconnectPort",
        "NtAlpcDeleteSecurityContext",
        "NtAlpcDeleteSectionView",
        "NtAlpcDeleteResourceReserve",
        "NtAlpcDeletePortSection",
        "NtAlpcCreateSecurityContext",
        "NtAlpcCreateSectionView",
        "NtAlpcCreateResourceReserve",
        "NtAlpcCreatePortSection",
        "NtAlpcCreatePort",
        "NtAlpcConnectPort",
        "NtAlpcConnectPortEx",
        "NtAlpcCancelMessage",
        "NtAlpcAcceptConnectPort",
        "NtAllocateVirtualMemory",
        "NtAllocateUuids",
        "NtAllocateUserPhysicalPages",
        "NtAllocateReserveObject",
        "NtAllocateLocallyUniqueId",
        "NtAlertThreadByThreadId",
        "NtAlertThread",
        "NtAlertResumeThread",
        "NtAdjustPrivilegesToken",
        "NtAdjustGroupsToken",
        "NtAdjustTokenClaimsAndDeviceGroups",
        "NtAddDriverEntry",
        "NtAddBootEntry",
        "NtAddAtom",
        "NtAddAtomEx",
        "NtAcquireProcessActivityReference",
        "NtAccessCheckByTypeResultListAndAuditAlarmByHandle",
        "NtAccessCheckByTypeResultListAndAuditAlarm",
        "NtAccessCheckByTypeResultList",
        "NtAccessCheckByTypeAndAuditAlarm",
        "NtAccessCheckByType",
        "NtAccessCheckAndAuditAlarm",
        "NtSetInformationSymbolicLink",
        "NtCreateRegistryTransaction",
        "NtOpenRegistryTransaction",
        "NtCommitRegistryTransaction",
        "NtRollbackRegistryTransaction"
    ],
    [
        "NtUserGetOwnerTransformedMonitorRect",
        "NtUserYieldTask",
        "NtUserSetSensorPresence",
        "NtGdiWidenPath",
        "NtGdiUpdateColors",
        "NtGdiUnrealizeObject",
        "NtGdiUnmapMemFont",
        "NtGdiUnloadPrinterDriver",
        "NtGdiTransparentBlt",
        "NtGdiTransformPoints",
        "NtGdiScaleRgn",
        "NtGdiScaleValues",
        "NtGdiGetDCDpiScaleValue",
        "NtGdiGetBitmapDpiScaleValue",
        "NtGdiSwapBuffers",
        "NtGdiStrokePath",
        "NtGdiStrokeAndFillPath",
        "NtGdiStretchDIBitsInternal",
        "NtGdiStretchBlt",
        "NtGdiStartPage",
        "NtGdiStartDoc",
        "NtGdiSetSizeDevice",
        "NtGdiSetVirtualResolution",
        "NtGdiSetTextJustification",
        "NtGdiSetSystemPaletteUse",
        "NtGdiSetRectRgn",
        "NtGdiSetPixelFormat",
        "NtGdiSetPixel",
        "NtGdiSetOPMSigningKeyAndSequenceNumbers",
        "NtGdiSetLayout",
        "NtGdiMirrorWindowOrg",
        "NtGdiGetDeviceWidth",
        "NtGdiSetMiterLimit",
        "NtGdiSetMetaRgn",
        "NtGdiSetMagicColors",
        "NtGdiSetLinkedUFIs",
        "NtGdiSetIcmMode",
        "NtGdiSetFontXform",
        "NtGdiSetFontEnumeration",
        "NtGdiSetDIBitsToDeviceInternal",
        "NtGdiSetDeviceGammaRamp",
        "NtGdiGetGammaRampCapability",
        "NtGdiSetPrivateDeviceGammaRamp",
        "NtGdiGetAppliedDeviceGammaRamp",
        "NtGdiSetColorSpace",
        "NtGdiSetColorAdjustment",
        "NtGdiSetBrushOrg",
        "NtGdiSetBrushAttributes",
        "NtGdiSetBoundsRect",
        "NtGdiSetBitmapDimension",
        "NtGdiSetBitmapBits",
        "NtGdiSetBitmapAttributes",
        "NtGdiSelectPen",
        "NtGdiSelectFont",
        "NtGdiSelectClipPath",
        "NtGdiSelectBrush",
        "NtGdiSelectBitmap",
        "NtGdiScaleWindowExtEx",
        "NtGdiScaleViewportExtEx",
        "NtGdiSaveDC",
        "NtGdiRoundRect",
        "NtGdiRestoreDC",
        "NtGdiResizePalette",
        "NtGdiResetDC",
        "NtGdiRemoveFontMemResourceEx",
        "NtGdiRemoveFontResourceW",
        "NtGdiRectVisible",
        "NtGdiRectInRegion",
        "NtGdiRectangle",
        "NtGdiQueryFontAssocInfo",
        "NtGdiQueryFonts",
        "NtGdiPtVisible",
        "NtGdiPtInRegion",
        "NtGdiPolyTextOutW",
        "NtGdiPolyPolyDraw",
        "NtGdiPolyDraw",
        "NtGdiPlgBlt",
        "NtGdiPathToRegion",
        "NtGdiPolyPatBlt",
        "NtGdiPatBlt",
        "NtGdiOpenDCW",
        "NtGdiOffsetRgn",
        "NtGdiOffsetClipRgn",
        "NtGdiMoveTo",
        "NtGdiMonoBitmap",
        "NtGdiModifyWorldTransform",
        "NtGdiMaskBlt",
        "NtGdiMakeInfoDC",
        "NtGdiMakeFontDir",
        "NtGdiLineTo",
        "NtGdiInvertRgn",
        "NtGdiIntersectClipRect",
        "NtGdiInitSpool",
        "NtGdiInit",
        "NtGdiIcmBrushInfo",
        "NtGdiHfontCreate",
        "NtGdiGradientFill",
        "NtGdiGetWidthTable",
        "NtGdiGetFontUnicodeRanges",
        "NtGdiAddEmbFontToDC",
        "NtGdiChangeGhostFont",
        "NtGdiGetEmbedFonts",
        "NtGdiGetUFIPathname",
        "NtGdiGetEmbUFI",
        "NtGdiGetUFI",
        "NtGdiGetTransform",
        "NtGdiGetTextMetricsW",
        "NtGdiGetTextFaceW",
        "NtGdiGetTextExtentExW",
        "NtGdiGetTextExtent",
        "NtGdiGetTextCharsetInfo",
        "NtGdiGetSystemPaletteUse",
        "NtGdiGetSuggestedOPMProtectedOutputArraySize",
        "NtGdiGetStringBitmapW",
        "NtGdiGetStats",
        "NtGdiGetSpoolMessage",
        "NtGdiGetServerMetaFileBits",
        "NtGdiGetRgnBox",
        "NtGdiGetRegionData",
        "NtGdiGetRealizationInfo",
        "NtGdiGetRasterizerCaps",
        "NtGdiGetRandomRgn",
        "NtGdiGetPixel",
        "NtGdiGetPath",
        "NtGdiGetOutlineTextMetricsInternalW",
        "NtGdiGetOPMRandomNumber",
        "NtGdiGetObjectBitmapHandle",
        "NtGdiGetNearestPaletteIndex",
        "NtGdiGetNearestColor",
        "NtGdiGetMonitorID",
        "NtGdiGetMiterLimit",
        "NtGdiGetLinkedUFIs",
        "NtGdiGetKerningPairs",
        "NtGdiGetOPMInformation",
        "NtGdiGetGlyphOutline",
        "NtGdiGetGlyphIndicesWInternal",
        "NtGdiGetGlyphIndicesW",
        "NtGdiGetFontResourceInfoInternalW",
        "NtGdiGetFontFileInfo",
        "NtGdiGetFontFileData",
        "NtGdiGetFontData",
        "NtGdiGetEudcTimeStampEx",
        "NtGdiGetETM",
        "NtGdiGetEntry",
        "NtGdiGetDIBitsInternal",
        "NtGdiGetDeviceCapsAll",
        "NtGdiGetDeviceGammaRamp",
        "NtGdiGetDeviceCaps",
        "NtGdiGetDCPoint",
        "NtGdiGetDCObject",
        "NtGdiGetDCforBitmap",
        "NtGdiGetDCDword",
        "NtGdiGetCurrentDpiInfo",
        "NtGdiGetCOPPCompatibleOPMInformation",
        "NtGdiGetColorSpaceforBitmap",
        "NtGdiGetColorAdjustment",
        "NtGdiGetCharWidthInfo",
        "NtGdiGetCharWidthW",
        "NtGdiGetCharSet",
        "NtGdiGetCharacterPlacementW",
        "NtGdiGetCharABCWidthsW",
        "NtGdiGetCertificateSize",
        "NtGdiGetCertificate",
        "NtGdiGetCertificateSizeByHandle",
        "NtGdiGetCertificateByHandle",
        "NtGdiGetBoundsRect",
        "NtGdiGetBitmapDimension",
        "NtGdiGetBitmapBits",
        "NtGdiGetAppClipBox",
        "NtGdiGetAndSetDCDword",
        "NtGdiFullscreenControl",
        "NtGdiFrameRgn",
        "NtGdiForceUFIMapping",
        "NtGdiFlush",
        "NtGdiFlattenPath",
        "NtGdiFillRgn",
        "NtGdiFillPath",
        "NtGdiExtTextOutW",
        "NtGdiExtSelectClipRgn",
        "NtGdiExtGetObjectW",
        "NtGdiExtFloodFill",
        "NtGdiExtEscape",
        "NtGdiExtCreateRegion",
        "NtGdiExtCreatePen",
        "NtGdiExcludeClipRect",
        "NtGdiEudcLoadUnloadLink",
        "NtGdiEqualRgn",
        "NtGdiEnumObjects",
        "NtGdiEnumFonts",
        "NtGdiEndPath",
        "NtGdiEndPage",
        "NtGdiEndGdiRendering",
        "NtGdiEndDoc",
        "NtGdiEnableEudc",
        "NtGdiEllipse",
        "NtGdiDrawEscape",
        "NtGdiDoPalette",
        "NtGdiDoBanding",
        "NtGdiGetPerBandInfo",
        "NtGdiDestroyOPMProtectedOutput",
        "NtGdiDescribePixelFormat",
        "NtGdiDeleteObjectApp",
        "NtGdiDeleteColorTransform",
        "NtGdiDeleteColorSpace",
        "NtGdiDeleteClientObj",
        "NtGdiCreateSolidBrush",
        "NtGdiCreateServerMetaFile",
        "NtGdiCreateRoundRectRgn",
        "NtGdiCreateRectRgn",
        "NtGdiCreatePen",
        "NtGdiCreatePatternBrushInternal",
        "NtGdiCreatePaletteInternal",
        "NtGdiCreateOPMProtectedOutputs",
        "NtGdiCreateOPMProtectedOutput",
        "NtGdiCreateMetafileDC",
        "NtGdiCreateHatchBrushInternal",
        "NtGdiCreateHalftonePalette",
        "NtGdiCreateEllipticRgn",
        "NtGdiCreateSessionMappedDIBSection",
        "NtGdiCreateDIBSection",
        "NtGdiCreateDIBitmapInternal",
        "NtGdiCreateDIBBrush",
        "NtGdiCreateCompatibleDC",
        "NtGdiCreateCompatibleBitmap",
        "NtGdiCreateColorTransform",
        "NtGdiCreateColorSpace",
        "NtGdiCreateClientObj",
        "NtGdiCreateBitmapFromDxSurface2",
        "NtGdiCreateBitmapFromDxSurface",
        "NtGdiCreateBitmap",
        "NtGdiConvertMetafileRect",
        "NtGdiConfigureOPMProtectedOutput",
        "NtGdiComputeXformCoefficients",
        "NtGdiCombineTransform",
        "NtGdiCombineRgn",
        "NtGdiColorCorrectPalette",
        "NtGdiClearBrushAttributes",
        "NtGdiClearBitmapAttributes",
        "NtGdiCloseFigure",
        "NtGdiCheckBitmapBits",
        "NtGdiCancelDC",
        "NtGdiBitBlt",
        "NtGdiBeginPath",
        "NtGdiBeginGdiRendering",
        "NtGdiArcInternal",
        "NtGdiFontIsLinked",
        "NtGdiAnyLinkedFonts",
        "NtGdiAngleArc",
        "NtGdiAlphaBlend",
        "NtGdiAddRemoteMMInstanceToDC",
        "NtGdiRemoveMergeFont",
        "NtGdiAddFontMemResourceEx",
        "NtGdiAddRemoteFontToDC",
        "NtGdiAddFontResourceW",
        "NtGdiAbortPath",
        "NtGdiAbortDoc",
        "NtUserDefSetText",
        "NtUserDeferWindowPosAndBand",
        "NtUserDdeInitialize",
        "NtUserCanBrokerForceForeground",
        "NtUserCreateWindowStation",
        "NtUserCreateWindowEx",
        "NtUserCreateLocalMemHandle",
        "NtUserCreateInputContext",
        "NtUserCreateDesktopEx",
        "NtUserCreateCaret",
        "NtUserCreateAcceleratorTable",
        "NtUserCountClipboardFormats",
        "NtUserCopyAcceleratorTable",
        "NtUserConvertMemHandle",
        "NtUserConsoleControl",
        "NtUserCloseWindowStation",
        "NtUserCloseDesktop",
        "NtUserCloseClipboard",
        "NtUserClipCursor",
        "NtUserChildWindowFromPointEx",
        "NtUserCheckMenuItem",
        "NtUserCheckWindowThreadDesktop",
        "NtUserDwmValidateWindow",
        "NtUserCheckAccessForIntegrityLevel",
        "NtUserDisplayConfigSetDeviceInfo",
        "NtUserDisplayConfigGetDeviceInfo",
        "NtUserQueryDisplayConfig",
        "NtUserSetDisplayConfig",
        "NtUserFunctionalizeDisplayConfig",
        "NtUserGetDisplayConfigBufferSizes",
        "NtUserChangeDisplaySettings",
        "NtUserChangeClipboardChain",
        "NtUserCallTwoParam",
        "NtUserCallOneParam",
        "NtUserCallNoParam",
        "NtUserCallNextHookEx",
        "NtUserCallMsgFilter",
        "NtUserCallHwndParamLock",
        "NtUserCallHwndParam",
        "NtUserCallHwndOpt",
        "NtUserCallHwndLock",
        "NtUserCallHwnd",
        "NtUserBroadcastThemeChangeEvent",
        "NtUserBuildPropList",
        "NtUserBuildNameList",
        "NtUserBuildHwndList",
        "NtUserBuildHimcList",
        "NtUserBlockInput",
        "NtUserBitBltSysBmp",
        "NtUserBeginPaint",
        "NtUserAttachThreadInput",
        "NtUserAssociateInputContext",
        "NtUserAlterWindowStyle",
        "NtUserAddClipboardFormatListener",
        "NtUserActivateKeyboardLayout",
        "NtUserDelegateCapturePointers",
        "NtUserDelegateInput",
        "NtUserDispatchMessage",
        "NtUserDisableProcessWindowFiltering",
        "NtUserDisableThreadIme",
        "NtUserDestroyWindow",
        "NtUserDestroyMenu",
        "NtUserDestroyInputContext",
        "NtUserDestroyCursor",
        "NtUserDestroyAcceleratorTable",
        "NtUserDeleteMenu",
        "NtUserDoSoundDisconnect",
        "NtUserDoSoundConnect",
        "NtUserGhostWindowFromHungWindow",
        "NtUserGetWOWClass",
        "NtUserGetWindowPlacement",
        "NtUserGetWindowDisplayAffinity",
        "NtUserGetWindowDC",
        "NtUserGetWindowCompositionAttribute",
        "NtUserGetWindowCompositionInfo",
        "NtUserGetWindowBand",
        "NtUserGetUpdateRgn",
        "NtUserGetUpdateRect",
        "NtUserGetUpdatedClipboardFormats",
        "NtUserGetTopLevelWindow",
        "NtUserGetTitleBarInfo",
        "NtUserGetThreadState",
        "NtUserGetThreadDesktop",
        "NtUserGetSystemMenu",
        "NtUserGetScrollBarInfo",
        "NtUserGetRegisteredRawInputDevices",
        "NtUserGetRawInputDeviceList",
        "NtUserGetRawInputDeviceInfo",
        "NtUserGetRawInputData",
        "NtUserGetRawInputBuffer",
        "NtUserGetProcessDpiAwarenessContext",
        "NtUserGetProcessWindowStation",
        "NtUserGetPriorityClipboardFormat",
        "NtUserGetOpenClipboardWindow",
        "NtUserGetObjectInformation",
        "NtUserGetMouseMovePointsEx",
        "NtUserGetMessage",
        "NtUserGetMenuItemRect",
        "NtUserGetMenuIndex",
        "NtUserGetMenuBarInfo",
        "NtUserGetListBoxInfo",
        "NtUserGetKeyState",
        "NtUserGetKeyNameText",
        "NtUserGetKeyboardState",
        "NtUserGetKeyboardLayoutName",
        "NtUserGetKeyboardLayoutList",
        "NtUserGetInternalWindowPos",
        "NtUserGetInputLocaleInfo",
        "NtUserGetImeInfoEx",
        "NtUserGetImeHotKey",
        "NtUserGetIconSize",
        "NtUserGetIconInfo",
        "NtUserGetGUIThreadInfo",
        "NtUserGetGuiResources",
        "NtUserGetForegroundWindow",
        "NtUserGetDoubleClickTime",
        "NtUserGetDesktopID",
        "NtUserGetDCEx",
        "NtUserGetDC",
        "NtUserGetCursorInfo",
        "NtUserGetCursorFrameInfo",
        "NtUserGetCurrentInputMessageSource",
        "NtUserGetCIMSSM",
        "NtUserGetCPD",
        "NtUserGetControlColor",
        "NtUserGetControlBrush",
        "NtUserGetComboBoxInfo",
        "NtUserGetClipCursor",
        "NtUserGetClipboardViewer",
        "NtUserGetClipboardSequenceNumber",
        "NtUserGetClipboardOwner",
        "NtUserGetClipboardFormatName",
        "NtUserGetClipboardData",
        "NtUserGetClassName",
        "NtUserGetClassInfoEx",
        "NtUserGetCaretPos",
        "NtUserGetCaretBlinkTime",
        "NtUserGetAtomName",
        "NtUserGetAsyncKeyState",
        "NtUserGetAppImeLevel",
        "NtUserGetAncestor",
        "NtUserGetAltTabInfo",
        "NtUserFrostCrashedWindow",
        "NtUserFlashWindowEx",
        "NtUserFindWindowEx",
        "NtUserFindExistingCursorIcon",
        "NtUserFillWindow",
        "NtUserExcludeUpdateRgn",
        "NtUserEvent",
        "NtUserEnumDisplaySettings",
        "NtUserEnumDisplayMonitors",
        "NtUserEnumDisplayDevices",
        "NtUserEndPaint",
        "NtUserEndMenu",
        "NtUserEndDeferWindowPosEx",
        "NtUserEnableScrollBar",
        "NtUserEnableMenuItem",
        "NtUserEmptyClipboard",
        "NtUserDrawMenuBarTemp",
        "NtUserDrawIconEx",
        "NtUserDrawCaptionTemp",
        "NtUserDrawCaption",
        "NtUserDrawAnimatedRects",
        "NtUserDragObject",
        "NtUserDragDetect",
        "NtUserHandleDelegatedInput",
        "NtUserInheritWindowMonitor",
        "NtUserRealChildWindowFromPoint",
        "NtUserQueryWindow",
        "NtUserQuerySendMessage",
        "NtUserQueryInputContext",
        "NtUserQueryInformationThread",
        "NtUserQueryBSDRWindow",
        "NtUserPerMonitorDPIPhysicalToLogicalPoint",
        "NtUserProcessConnect",
        "NtUserPrintWindow",
        "NtUserPostThreadMessage",
        "NtUserPostMessage",
        "NtUserPhysicalToLogicalPoint",
        "NtUserPeekMessage",
        "NtUserPaintMonitor",
        "NtUserPaintDesktop",
        "NtUserOpenWindowStation",
        "NtUserOpenThreadDesktop",
        "NtUserOpenInputDesktop",
        "NtUserOpenDesktop",
        "NtUserOpenClipboard",
        "NtUserNotifyWinEvent",
        "NtUserNotifyProcessCreate",
        "NtUserNotifyIMEStatus",
        "NtUserMoveWindow",
        "NtUserModifyUserStartupInfoFlags",
        "NtUserMNDragOver",
        "NtUserMNDragLeave",
        "NtUserMinMaximize",
        "NtUserMessageCall",
        "NtUserMenuItemFromPoint",
        "NtUserMapVirtualKeyEx",
        "NtUserLayoutCompleted",
        "NtUserLogicalToPerMonitorDPIPhysicalPoint",
        "NtUserLogicalToPhysicalPoint",
        "NtUserLockCursor",
        "NtUserLockWorkStation",
        "NtUserLockWindowUpdate",
        "NtUserLockWindowStation",
        "NtUserLoadKeyboardLayoutEx",
        "NtUserKillTimer",
        "NtUserIsTopLevelWindow",
        "NtUserIsClipboardFormatAvailable",
        "NtUserInvalidateRgn",
        "NtUserInvalidateRect",
        "NtUserInternalGetWindowIcon",
        "NtUserInternalGetWindowText",
        "NtUserInitTask",
        "NtUserInitializeClientPfnArrays",
        "NtUserInitialize",
        "NtUserImpersonateDdeClientWindow",
        "NtUserHungWindowFromGhostWindow",
        "NtUserHiliteMenuItem",
        "NtUserHideCaret",
        "NtUserHardErrorControl",
        "NtUserRealInternalGetMessage",
        "NtUserRealWaitMessageEx",
        "NtUserReleaseDwmHitTestWaiters",
        "NtUserTranslateMessage",
        "NtUserTranslateAccelerator",
        "NtUserPaintMenuBar",
        "NtUserCalcMenuBar",
        "NtUserCalculatePopupWindowPosition",
        "NtUserTrackPopupMenuEx",
        "NtUserTrackMouseEvent",
        "NtUserToUnicodeEx",
        "NtUserThunkedMenuItemInfo",
        "NtUserThunkedMenuInfo",
        "NtUserTestForInteractiveUser",
        "NtUserSendEventMessage",
        "NtUserSystemParametersInfo",
        "NtUserSystemParametersInfoForDpi",
        "NtUserSwitchDesktop",
        "NtUserSoundSentry",
        "NtUserShutdownReasonDestroy",
        "NtUserShutdownBlockReasonQuery",
        "NtUserShutdownBlockReasonCreate",
        "NtUserShowWindowAsync",
        "NtUserShowWindow",
        "NtUserShowScrollBar",
        "NtUserShowCaret",
        "NtUserSetWinEventHook",
        "NtUserSetWindowWord",
        "NtUserSetWindowStationUser",
        "NtUserSetWindowsHookEx",
        "NtUserSetWindowsHookAW",
        "NtUserSetWindowRgnEx",
        "NtUserGetWindowRgnEx",
        "NtUserSetWindowRgn",
        "NtUserSetWindowPos",
        "NtUserSetWindowPlacement",
        "NtUserSetWindowLong",
        "NtUserSetWindowFNID",
        "NtUserSetWindowDisplayAffinity",
        "NtUserSetWindowCompositionTransition",
        "NtUserUpdateDefaultDesktopThumbnail",
        "NtUserSetWindowCompositionAttribute",
        "NtUserSetWindowBand",
        "NtUserSetProcessUIAccessZorder",
        "NtUserSetProcessDpiAwarenessContext",
        "NtUserEnableChildWindowDpiMessage",
        "NtUserIsChildWindowDpiMessageEnabled",
        "NtUserEnableNonClientDpiScaling",
        "NtUserIsNonClientDpiScalingEnabled",
        "NtUserSetDialogControlDpiChangeBehavior",
        "NtUserIsWindowBroadcastingDpiToChildren",
        "NtUserEnableWindowGDIScaledDpiMessage",
        "NtUserIsWindowGDIScaledDpiMessageEnabled",
        "NtUserSetTimer",
        "NtUserSetThreadState",
        "NtUserSetThreadLayoutHandles",
        "NtUserSetThreadDesktop",
        "NtUserSetThreadInputBlocked",
        "NtUserSetSystemTimer",
        "NtUserSetSystemMenu",
        "NtUserSetSystemCursor",
        "NtUserSetSysColors",
        "NtUserSetShellWindowEx",
        "NtUserSetScrollInfo",
        "NtUserSetProp",
        "NtUserGetProp",
        "NtUserSetProcessWindowStation",
        "NtUserSetParent",
        "NtUserSetObjectInformation",
        "NtUserSetMenuFlagRtoL",
        "NtUserSetMenuDefaultItem",
        "NtUserSetMenuContextHelpId",
        "NtUserSetMenu",
        "NtUserSetKeyboardState",
        "NtUserSetInternalWindowPos",
        "NtUserSetInformationThread",
        "NtUserSetImeOwnerWindow",
        "NtUserSetImeInfoEx",
        "NtUserSetImeHotKey",
        "NtUserSetFocus",
        "NtUserSetCursorIconData",
        "NtUserSetCursorContents",
        "NtUserSetCursor",
        "NtUserSetClipboardViewer",
        "NtUserSetClipboardData",
        "NtUserSetClassWord",
        "NtUserSetClassLong",
        "NtUserSetChildWindowNoActivate",
        "NtUserSetCapture",
        "NtUserSetAppImeLevel",
        "NtUserSetActiveWindow",
        "NtUserSendInput",
        "NtUserSelectPalette",
        "NtUserScrollWindowEx",
        "NtUserScrollDC",
        "NtUserSBGetParms",
        "NtUserResolveDesktopForWOW",
        "NtUserRemoveProp",
        "NtUserRemoveMenu",
        "NtUserRemoveClipboardFormatListener",
        "NtUserRegisterWindowMessage",
        "NtUserRegisterTasklist",
        "NtUserRegisterServicesProcess",
        "NtUserRegisterRawInputDevices",
        "NtUserRegisterHotKey",
        "NtUserRegisterDManipHook",
        "NtUserGetDManipHookInitFunction",
        "NtUserRegisterManipulationThread",
        "NtUserSetManipulationInputTarget",
        "NtUserRegisterUserApiHook",
        "NtUserRegisterErrorReportingDialog",
        "NtUserRegisterClassExWOW",
        "NtUserRegisterBSDRWindow",
        "NtUserRedrawWindow",
        "NtUserUndelegateInput",
        "NtUserGetWindowMinimizeRect",
        "NtUserDwmGetRemoteSessionOcclusionEvent",
        "NtUserDwmGetRemoteSessionOcclusionState",
        "NtUserDwmKernelShutdown",
        "NtUserDwmKernelStartup",
        "NtUserCheckProcessSession",
        "NtUserUnregisterSessionPort",
        "NtUserRegisterSessionPort",
        "NtUserCtxDisplayIOCtl",
        "NtUserRemoteStopScreenUpdates",
        "NtUserRemoteRedrawScreen",
        "NtUserRemoteRedrawRectangle",
        "NtUserRemoteConnect",
        "NtUserWaitAvailableMessageEx",
        "NtUserWindowFromPoint",
        "NtUserWindowFromPhysicalPoint",
        "NtUserWaitMessage",
        "NtUserWaitForMsgAndEvent",
        "NtUserWaitForInputIdle",
        "NtUserVkKeyScanEx",
        "NtUserValidateTimerCallback",
        "NtUserValidateRect",
        "NtUserValidateHandleSecure",
        "NtUserUserHandleGrantAccess",
        "NtUserUpdatePerUserSystemParameters",
        "NtUserSetLayeredWindowAttributes",
        "NtUserGetLayeredWindowAttributes",
        "NtUserUpdateLayeredWindow",
        "NtUserUpdateInstance",
        "NtUserUpdateInputContext",
        "NtUserUnregisterHotKey",
        "NtUserUnregisterUserApiHook",
        "NtUserUnregisterClass",
        "NtUserUnlockWindowStation",
        "NtUserUnloadKeyboardLayout",
        "NtUserUnhookWinEvent",
        "NtUserUnhookWindowsHookEx",
        "NtUserGetTouchInputInfo",
        "NtUserIsTouchWindow",
        "NtUserModifyWindowTouchCapability",
        "NtGdiEngStretchBltROP",
        "NtGdiEngTextOut",
        "NtGdiEngTransparentBlt",
        "NtGdiEngGradientFill",
        "NtGdiEngAlphaBlend",
        "NtGdiEngLineTo",
        "NtGdiEngPaint",
        "NtGdiEngStrokeAndFillPath",
        "NtGdiEngFillPath",
        "NtGdiEngStrokePath",
        "NtGdiEngMarkBandingSurface",
        "NtGdiEngPlgBlt",
        "NtGdiEngStretchBlt",
        "NtGdiEngBitBlt",
        "NtGdiEngLockSurface",
        "NtGdiEngUnlockSurface",
        "NtGdiEngEraseSurface",
        "NtGdiEngDeleteSurface",
        "NtGdiEngDeletePalette",
        "NtGdiEngCopyBits",
        "NtGdiEngComputeGlyphSet",
        "NtGdiEngCreatePalette",
        "NtGdiEngCreateDeviceBitmap",
        "NtGdiEngCreateDeviceSurface",
        "NtGdiEngCreateBitmap",
        "NtGdiEngAssociateSurface",
        "NtUserSetWindowFeedbackSetting",
        "NtUserRegisterEdgy",
        "NtUserRegisterShellPTPListener",
        "NtUserGetWindowFeedbackSetting",
        "NtUserHidePointerContactVisualization",
        "NtUserGetTouchValidationStatus",
        "NtUserInitializeTouchInjection",
        "NtUserInjectTouchInput",
        "NtUserRegisterTouchHitTestingWindow",
        "NtUserSetDisplayMapping",
        "NtUserSetCalibrationData",
        "NtUserGetPhysicalDeviceRect",
        "NtUserRegisterTouchPadCapable",
        "NtUserGetRawPointerDeviceData",
        "NtUserGetPointerDeviceCursors",
        "NtUserGetPointerDeviceRects",
        "NtUserRegisterPointerDeviceNotifications",
        "NtUserGetPointerDeviceProperties",
        "NtUserGetPointerDevice",
        "NtUserGetPointerDevices",
        "NtUserEnableTouchPad",
        "NtUserGetPrecisionTouchPadConfiguration",
        "NtUserSetPrecisionTouchPadConfiguration",
        "NtUserPromotePointer",
        "NtUserDiscardPointerFrameMessages",
        "NtUserRegisterPointerInputTarget",
        "NtUserGetPointerFrameArrivalTimes",
        "NtUserGetPointerInputTransform",
        "NtUserGetPointerInfoList",
        "NtUserGetPointerCursorId",
        "NtUserGetPointerType",
        "NtUserGetGestureConfig",
        "NtUserSetGestureConfig",
        "NtUserGetGestureExtArgs",
        "NtUserGetGestureInfo",
        "NtUserInjectGesture",
        "NtUserChangeWindowMessageFilterEx",
        "NtGdiXLATEOBJ_hGetColorTransform",
        "NtGdiXLATEOBJ_iXlate",
        "NtGdiXLATEOBJ_cGetPalette",
        "NtGdiEngDeleteClip",
        "NtGdiEngCreateClip",
        "NtGdiEngDeletePath",
        "NtGdiCLIPOBJ_ppoGetPath",
        "NtGdiCLIPOBJ_cEnumStart",
        "NtGdiCLIPOBJ_bEnum",
        "NtGdiBRUSHOBJ_hGetColorTransform",
        "NtGdiBRUSHOBJ_pvGetRbrush",
        "NtGdiBRUSHOBJ_pvAllocRbrush",
        "NtGdiBRUSHOBJ_ulGetBrushColor",
        "NtGdiXFORMOBJ_iGetXform",
        "NtGdiXFORMOBJ_bApplyXform",
        "NtGdiFONTOBJ_pQueryGlyphAttrs",
        "NtGdiFONTOBJ_pfdg",
        "NtGdiFONTOBJ_pifi",
        "NtGdiFONTOBJ_cGetGlyphs",
        "NtGdiFONTOBJ_pxoGetXform",
        "NtGdiFONTOBJ_vGetInfo",
        "NtGdiFONTOBJ_cGetAllGlyphHandles",
        "NtGdiFONTOBJ_pvTrueTypeFontFile",
        "NtGdiSTROBJ_dwGetCodePage",
        "NtGdiSTROBJ_vEnumStart",
        "NtGdiSTROBJ_bGetAdvanceWidths",
        "NtGdiSTROBJ_bEnumPositionsOnly",
        "NtGdiSTROBJ_bEnum",
        "NtGdiPATHOBJ_bEnumClipLines",
        "NtGdiPATHOBJ_vEnumStartClipLines",
        "NtGdiPATHOBJ_vEnumStart",
        "NtGdiPATHOBJ_bEnum",
        "NtGdiPATHOBJ_vGetBounds",
        "NtGdiEngCheckAbort",
        "NtGdiGetDhpdev",
        "NtGdiHT_Get8BPPMaskPalette",
        "NtGdiHT_Get8BPPFormatPalette",
        "NtGdiUpdateTransform",
        "NtGdiUMPDEngFreeUserMem",
        "NtGdiBRUSHOBJ_DeleteRbrush",
        "NtGdiSetPUMPDOBJ",
        "NtGdiSetUMPDSandboxState",
        "NtGdiDrawStream",
        "NtGdiHLSurfSetInformation",
        "NtGdiHLSurfGetInformation",
        "NtGdiDwmCreatedBitmapRemotingOutput",
        "NtGdiDdDDIGetScanLine",
        "NtGdiDdDDIReleaseProcessVidPnSourceOwners",
        "NtGdiDdDDIGetProcessSchedulingPriorityClass",
        "NtGdiDdDDISetProcessSchedulingPriorityClass",
        "NtGdiDdDDIGetContextSchedulingPriority",
        "NtGdiDdDDISetContextSchedulingPriority",
        "NtGdiDdDDIDestroyDCFromMemory",
        "NtGdiDdDDICreateDCFromMemory",
        "NtGdiDdDDIGetDeviceState",
        "NtGdiDdDDISetGammaRamp",
        "NtGdiDdDDIWaitForVerticalBlankEvent",
        "NtGdiDdDDIDestroyOverlay",
        "NtGdiDdDDIFlipOverlay",
        "NtGdiDdDDIUpdateOverlay",
        "NtGdiDdDDICreateOverlay",
        "NtGdiDdDDIGetPresentQueueEvent",
        "NtGdiDdDDIGetPresentHistory",
        "NtGdiDdDDISetVidPnSourceOwner1",
        "NtGdiDdDDISetVidPnSourceOwner",
        "NtGdiDdDDIQueryStatistics",
        "NtGdiDdDDIEscape",
        "NtGdiDdDDIGetSharedPrimaryHandle",
        "NtGdiDdDDICloseAdapter",
        "NtGdiDdDDIOpenAdapterFromLuid",
        "NtGdiDdDDIEnumAdapters",
        "NtGdiDdDDIEnumAdapters2",
        "NtGdiDdDDIOpenAdapterFromHdc",
        "NtGdiDdDDIOpenAdapterFromDeviceName",
        "NtGdiDdDDIRender",
        "NtGdiDdDDIPresent",
        "NtGdiDdDDIGetMultisampleMethodList",
        "NtGdiDdDDISetDisplayMode",
        "NtGdiDdDDIGetDisplayModeList",
        "NtGdiDdDDIUnlock",
        "NtGdiDdDDILock",
        "NtGdiDdDDIQueryAdapterInfo",
        "NtGdiDdDDIGetRuntimeData",
        "NtGdiDdDDISignalSynchronizationObject",
        "NtGdiDdDDIWaitForSynchronizationObject",
        "NtGdiDdDDIDestroySynchronizationObject",
        "NtGdiDdDDIOpenSynchronizationObject",
        "NtGdiDdDDICreateSynchronizationObject",
        "NtGdiDdDDIDestroyContext",
        "NtGdiDdDDICreateContext",
        "NtGdiDdDDIDestroyDevice",
        "NtGdiDdDDICreateDevice",
        "NtGdiDdDDIQueryAllocationResidency",
        "NtGdiDdDDISetAllocationPriority",
        "NtGdiDdDDIDestroyAllocation",
        "NtGdiDdDDIDestroyAllocation2",
        "NtGdiDdDDIOpenResourceFromNtHandle",
        "NtGdiDdDDIOpenSyncObjectFromNtHandle",
        "NtGdiDdDDIOpenSyncObjectFromNtHandle2",
        "NtGdiDdDDIOpenResource",
        "NtGdiDdDDIOpenNtHandleFromName",
        "NtGdiDdDDIOpenSyncObjectNtHandleFromName",
        "NtGdiDdDDIShareObjects",
        "NtGdiDdDDIQueryResourceInfoFromNtHandle",
        "NtGdiDdDDIQueryResourceInfo",
        "NtGdiDdDDICreateAllocation",
        "NtGdiDdDDIOutputDuplReleaseFrame",
        "NtGdiDdDDIQueryRemoteVidPnSourceFromGdiDisplayName",
        "NtGdiDdDDIOutputDuplPresent",
        "NtGdiDdDDIReleaseKeyedMutex2",
        "NtGdiDdDDIAcquireKeyedMutex2",
        "NtGdiDdDDIOpenKeyedMutex2",
        "NtGdiDdDDICreateKeyedMutex2",
        "NtGdiDdDDIOutputDuplGetPointerShapeData",
        "NtGdiDdDDIOutputDuplGetMetaData",
        "NtGdiDdDDIOutputDuplGetFrameInfo",
        "NtGdiDdDDIDestroyOutputDupl",
        "NtGdiDdDDICreateOutputDupl",
        "NtGdiDdDDIReclaimAllocations",
        "NtGdiDdDDIOfferAllocations",
        "NtGdiDdDDICheckSharedResourceAccess",
        "NtGdiDdDDICheckVidPnExclusiveOwnership",
        "NtGdiDdDDIGetOverlayState",
        "NtGdiDdDDIConfigureSharedResource",
        "NtGdiDdDDIReleaseKeyedMutex",
        "NtGdiDdDDIAcquireKeyedMutex",
        "NtGdiDdDDIDestroyKeyedMutex",
        "NtGdiDdDDIOpenKeyedMutex",
        "NtGdiDdDDICreateKeyedMutex",
        "NtGdiDdDDISharedPrimaryUnLockNotification",
        "NtGdiDdDDISharedPrimaryLockNotification",
        "NtGdiDdDDISetDisplayPrivateDriverFormat",
        "NtGdiDdDDICheckExclusiveOwnership",
        "NtGdiDdDDICheckMonitorPowerState",
        "NtGdiDdDDIWaitForIdle",
        "NtGdiDdDDICheckOcclusion",
        "NtGdiDdDDIInvalidateActiveVidPn",
        "NtGdiDdDDIPollDisplayChildren",
        "NtGdiDdDDISetQueuedLimit",
        "NtGdiDdDDIPinDirectFlipResources",
        "NtGdiDdDDIUnpinDirectFlipResources",
        "NtGdiDdDDIWaitForVerticalBlankEvent2",
        "NtGdiDdDDIGetDWMVerticalBlankEvent",
        "NtGdiDdDDISetSyncRefreshCountWaitTarget",
        "NtGdiDdDDISetContextInProcessSchedulingPriority",
        "NtGdiDdDDIGetContextInProcessSchedulingPriority",
        "NtGdiDdDDIGetSharedResourceAdapterLuid",
        "NtGdiDdDDISetStereoEnabled",
        "NtGdiDdDDIPresentMultiPlaneOverlay",
        "NtGdiDdDDICheckMultiPlaneOverlaySupport",
        "NtGdiDdDDIMakeResident",
        "NtGdiDdDDIEvict",
        "NtGdiDdDDIUpdateAllocationProperty",
        "NtGdiDdDDIWaitForSynchronizationObjectFromCpu",
        "NtGdiDdDDISignalSynchronizationObjectFromCpu",
        "NtGdiDdDDIWaitForSynchronizationObjectFromGpu",
        "NtGdiDdDDISignalSynchronizationObjectFromGpu",
        "NtGdiDdDDISignalSynchronizationObjectFromGpu2",
        "NtGdiDdDDICreatePagingQueue",
        "NtGdiDdDDIDestroyPagingQueue",
        "NtGdiDdDDILock2",
        "NtGdiDdDDIUnlock2",
        "NtGdiDdDDIInvalidateCache",
        "NtGdiDdDDIGetResourcePresentPrivateDriverData",
        "NtGdiDdDDIMapGpuVirtualAddress",
        "NtGdiDdDDIReserveGpuVirtualAddress",
        "NtGdiDdDDIFreeGpuVirtualAddress",
        "NtGdiDdDDIUpdateGpuVirtualAddress",
        "NtGdiDdDDICreateContextVirtual",
        "NtGdiDdDDISubmitCommand",
        "NtGdiDdDDIGetCachedHybridQueryValue",
        "NtGdiDdDDICacheHybridQueryValue",
        "NtGdiDdDDINetDispGetNextChunkInfo",
        "NtGdiDdDDINetDispQueryMiracastDisplayDeviceSupport",
        "NtGdiDdDDINetDispStartMiracastDisplayDevice",
        "NtGdiDdDDINetDispStopMiracastDisplayDevice",
        "NtGdiDdDDINetDispQueryMiracastDisplayDeviceStatus",
        "NtGdiDdDDINetDispStopSessions",
        "NtGdiDdDDIQueryVideoMemoryInfo",
        "NtGdiDdDDIChangeVideoMemoryReservation",
        "NtGdiDdDDICreateSwapChain",
        "NtGdiDdDDIOpenSwapChain",
        "NtGdiDdDDIGetSetSwapChainMetadata",
        "NtGdiDdDDIAcquireSwapChain",
        "NtGdiDdDDIReleaseSwapChain",
        "NtGdiDdDDIAbandonSwapChain",
        "NtGdiDdDDISetDodIndirectSwapchain",
        "NtGdiDdDDICheckMultiPlaneOverlaySupport2",
        "NtGdiDdDDIPresentMultiPlaneOverlay2",
        "NtGdiDdDDIReclaimAllocations2",
        "NtGdiDdDDISetStablePowerState",
        "NtGdiDdDDIQueryClockCalibration",
        "NtGdiDdDDIQueryVidPnExclusiveOwnership",
        "NtGdiDdDDIAdjustFullscreenGamma",
        "NtGdiDdDDISetVidPnSourceHwProtection",
        "NtGdiDdDDIMarkDeviceAsError",
        "NtGdiDdDDIFlushHeapTransitions",
        "NtGdiDdDDISetHwProtectionTeardownRecovery",
        "NtGdiDdDDIQueryProcessOfferInfo",
        "NtGdiDdDDITrimProcessCommitment",
        "NtGdiDdDDICheckMultiPlaneOverlaySupport3",
        "NtGdiDdDDIPresentMultiPlaneOverlay3",
        "NtGdiDdDDISetFSEBlock",
        "NtGdiDdDDIQueryFSEBlock",
        "NtGdiDdDDICreateHwContext",
        "NtGdiDdDDIDestroyHwContext",
        "NtGdiDdDDICreateHwQueue",
        "NtGdiDdDDIDestroyHwQueue",
        "NtGdiDdDDISubmitCommandToHwQueue",
        "NtGdiDdDDISubmitWaitForSyncObjectsToHwQueue",
        "NtGdiDdDDISubmitSignalSyncObjectsToHwQueue",
        "NtGdiDdDDIGetAllocationPriority",
        "NtGdiDdDDIGetMultiPlaneOverlayCaps",
        "NtGdiDdDDIGetPostCompositionCaps",
        "NtGdiDdDDISetYieldPercentage",
        "NtGdiDdDDISetProcessSchedulingPriorityBand",
        "NtGdiDdDDISetMemoryBudgetTarget",
        "NtGdiDdDDIGetYieldPercentage",
        "NtGdiDdDDIGetProcessSchedulingPriorityBand",
        "NtGdiDdDDIGetMemoryBudgetTarget",
        "NtGdiMakeObjectUnXferable",
        "NtGdiMakeObjectXferable",
        "NtGdiDestroyPhysicalMonitor",
        "NtGdiGetPhysicalMonitorDescription",
        "NtGdiGetPhysicalMonitors",
        "NtGdiGetNumberOfPhysicalMonitors",
        "NtGdiDDCCIGetTimingReport",
        "NtGdiDDCCIGetCapabilitiesString",
        "NtGdiDDCCIGetCapabilitiesStringLength",
        "NtGdiDDCCISaveCurrentSettings",
        "NtGdiDDCCISetVCPFeature",
        "NtGdiDDCCIGetVCPFeature",
        "NtGdiDdQueryVisRgnUniqueness",
        "NtGdiDdDestroyFullscreenSprite",
        "NtGdiDdNotifyFullscreenSpriteUpdate",
        "NtGdiDdCreateFullscreenSprite",
        "NtGdiGetProcessSessionFonts",
        "NtGdiGetPublicFontTableChangeCookie",
        "NtGdiAddInitialFonts",
        "NtUserShowSystemCursor",
        "NtUserSetMirrorRendering",
        "NtUserMagGetContextInformation",
        "NtUserMagSetContextInformation",
        "NtUserMagControl",
        "NtUserSlicerControl",
        "NtUserHwndSetRedirectionInfo",
        "NtUserHwndQueryRedirectionInfo",
        "NtCreateCompositionSurfaceHandle",
        "NtValidateCompositionSurfaceHandle",
        "NtBindCompositionSurface",
        "NtUnBindCompositionSurface",
        "NtQueryCompositionSurfaceBinding",
        "NtNotifyPresentToCompositionSurface",
        "NtQueryCompositionSurfaceStatistics",
        "NtOpenCompositionSurfaceSectionInfo",
        "NtOpenCompositionSurfaceSwapChainHandleInfo",
        "NtQueryCompositionSurfaceRenderingRealization",
        "NtOpenCompositionSurfaceDirtyRegion",
        "NtQueryCompositionSurfaceHDRMetaData",
        "NtSetCompositionSurfaceHDRMetaData",
        "NtSetCompositionSurfaceDirectFlipState",
        "NtSetCompositionSurfaceStatistics",
        "NtSetCompositionSurfaceBufferUsage",
        "NtSetCompositionSurfaceIndependentFlipInfo",
        "NtDesktopCaptureBits",
        "NtDCompositionEnableMMCSS",
        "NtVisualCaptureBits",
        "NtDCompositionEnableDDASupport",
        "NtDCompositionCreateSharedVisualHandle",
        "NtCreateCompositionInputSink",
        "NtCreateImplicitCompositionInputSink",
        "NtDuplicateCompositionInputSink",
        "NtQueryCompositionInputSink",
        "NtQueryCompositionInputSinkLuid",
        "NtQueryCompositionInputSinkViewId",
        "NtUpdateInputSinkTransforms",
        "NtCompositionInputThread",
        "NtQueryCompositionInputQueueAndTransform",
        "NtQueryCompositionInputIsImplicit",
        "NtCompositionSetDropTarget",
        "NtTokenManagerOpenSectionAndEvents",
        "NtTokenManagerThread",
        "NtTokenManagerCreateCompositionTokenHandle",
        "NtTokenManagerGetAnalogExclusiveTokenEvent",
        "NtTokenManagerGetAnalogExclusiveSurfaceUpdates",
        "NtTokenManagerConfirmOutstandingAnalogToken",
        "NtSetCompositionSurfaceAnalogExclusive",
        "NtDCompositionBeginFrame",
        "NtDCompositionConfirmFrame",
        "NtDCompositionRetireFrame",
        "NtDCompositionDiscardFrame",
        "NtDCompositionGetFrameSurfaceUpdates",
        "NtDCompositionGetFrameLegacyTokens",
        "NtDCompositionDestroyConnection",
        "NtDCompositionGetConnectionBatch",
        "NtDCompositionGetFrameStatistics",
        "NtDCompositionGetDeletedResources",
        "NtDCompositionCreateConnection",
        "NtDCompositionDestroyChannel",
        "NtDCompositionReleaseAllResources",
        "NtDCompositionSubmitDWMBatch",
        "NtDCompositionProcessChannelBatchBuffer",
        "NtDCompositionCommitChannel",
        "NtDCompositionWaitForChannel",
        "NtDCompositionSetChannelCommitCompletionEvent",
        "NtDCompositionTelemetryTouchInteractionBegin",
        "NtDCompositionTelemetryTouchInteractionUpdate",
        "NtDCompositionTelemetryTouchInteractionEnd",
        "NtDCompositionTelemetrySetApplicationId",
        "NtDCompositionTelemetryAnimationScenarioBegin",
        "NtDCompositionTelemetryAnimationScenarioReference",
        "NtDCompositionTelemetryAnimationScenarioUnreference",
        "NtDCompositionCurrentBatchId",
        "NtDCompositionRemoveCrossDeviceVisualChild",
        "NtDCompositionAddCrossDeviceVisualChild",
        "NtDCompositionCreateDwmChannel",
        "NtDCompositionCreateChannel",
        "NtDCompositionSynchronize",
        "NtDCompositionReferenceSharedResourceOnDwmChannel",
        "NtDCompositionCreateAndBindSharedSection",
        "NtDCompositionSetDebugCounter",
        "NtDCompositionGetChannels",
        "NtDCompositionConnectPipe",
        "NtDCompositionRegisterThumbnailVisual",
        "NtDCompositionRegisterVirtualDesktopVisual",
        "NtDCompositionDuplicateHandleToProcess",
        "NtDCompositionUpdatePointerCapture",
        "NtDCompositionSetChannelCallbackId",
        "NtDCompositionDuplicateSwapchainHandleToDwm",
        "NtDCompositionSetChildRootVisual",
        "NtDCompositionCommitSynchronizationObject",
        "NtUserDestroyDCompositionHwndTarget",
        "NtUserCreateDCompositionHwndTarget",
        "NtUserWaitForRedirectionStartComplete",
        "NtUserSignalRedirectionStartComplete",
        "NtUserEnableWindowResizeOptimization",
        "NtUserGetResizeDCompositionSynchronizationObject",
        "NtUserEnableResizeLayoutSynchronization",
        "NtUserBeginLayoutUpdate",
        "NtUserIsResizeLayoutSynchronizationEnabled",
        "NtUserConfirmResizeCommit",
        "NtUserSetActiveProcessForMonitor",
        "NtUserGetDisplayAutoRotationPreferencesByProcessId",
        "NtUserGetDisplayAutoRotationPreferences",
        "NtUserSetDisplayAutoRotationPreferences",
        "NtUserSetAutoRotation",
        "NtUserGetAutoRotationState",
        "NtUserAutoRotateScreen",
        "NtUserAcquireIAMKey",
        "NtUserSetActivationFilter",
        "NtUserSetFallbackForeground",
        "NtUserSetBrokeredForeground",
        "NtUserDisableImmersiveOwner",
        "NtUserClearForeground",
        "NtUserEnableIAMAccess",
        "NtUserGetProcessUIContextInformation",
        "NtUserSetProcessRestrictionExemption",
        "NtUserSetWindowArrangement",
        "NtUserSetWindowShowState",
        "NtUserUpdateWindowTrackingInfo",
        "NtUserEnableMouseInPointer",
        "NtUserIsMouseInPointerEnabled",
        "NtUserPromoteMouseInPointer",
        "NtUserAutoPromoteMouseInPointer",
        "NtUserEnableMouseInputForCursorSuppression",
        "NtUserIsMouseInputEnabled",
        "NtUserCheckProcessForClipboardAccess",
        "NtUserGetClipboardAccessToken",
        "NtUserGetQueueStatusReadonly",
        "NtUserCompositionInputSinkLuidFromPoint",
        "NtUserCompositionInputSinkViewInstanceIdFromPoint",
        "NtUserUpdateWindowInputSinkHints",
        "NtUserTransformPoint",
        "NtUserTransformRect",
        "NtUserGetHimetricScaleFactorFromPixelLocation",
        "NtUserGetDpiForMonitor",
        "NtUserReportInertia",
        "NtUserLinkDpiCursor",
        "NtUserGetCursorDims",
        "NtUserInitializeInputDeviceInjection",
        "NtUserInitializeGenericHidInjection",
        "NtUserInitializePointerDeviceInjection",
        "NtUserRemoveInjectionDevice",
        "NtUserSetFeatureReportResponse",
        "NtUserInjectDeviceInput",
        "NtUserInjectMouseInput",
        "NtUserInjectKeyboardInput",
        "NtUserInjectPointerInput",
        "NtUserInjectGenericHidInput",
        "NtUserInitializePointerDeviceInjectionEx",
        "NtRIMRegisterForInput",
        "NtRIMReadInput",
        "NtRIMGetDevicePreparsedData",
        "NtRIMGetDeviceProperties",
        "NtRIMAreSiblingDevices",
        "NtRIMFreeInputBuffer",
        "NtRIMOnPnpNotification",
        "NtRIMOnTimerNotification",
        "NtRIMDeviceIoControl",
        "NtRIMUnregisterForInput",
        "NtRIMSetTestModeStatus",
        "NtRIMGetPhysicalDeviceRect",
        "NtRIMGetSourceProcessId",
        "NtRIMAddInputObserver",
        "NtRIMRemoveInputObserver",
        "NtRIMUpdateInputObserverRegistration",
        "NtRIMObserveNextInput",
        "NtRIMGetDevicePreparsedDataLockfree",
        "NtRIMGetDevicePropertiesLockfree",
        "NtUserSetCoreWindow",
        "NtUserSetCoreWindowPartner",
        "NtUserNavigateFocus",
        "NtHWCursorUpdatePointer",
        "NtUserAcquireInteractiveControlBackgroundAccess",
        "NtUserGetInteractiveControlInfo",
        "NtUserGetInteractiveControlDeviceInfo",
        "NtUserSendInteractiveControlHapticsReport",
        "NtUserSetInteractiveControlFocus",
        "NtUserInteractiveControlQueryUsage",
        "NtUserSetInteractiveCtrlRotationAngle",
        "NtUserGetInteractiveCtrlSupportedWaveforms",
        "NtUserProcessInkFeedbackCommand",
        "NtUserSetProcessInteractionFlags",
        "NtMITActivateInputProcessing",
        "NtMITWaitForMultipleObjectsEx",
        "NtMITDeactivateInputProcessing",
        "NtMITSetInputCallbacks",
        "NtMITCoreMsgKGetConnectionHandle",
        "NtMITCoreMsgKSend",
        "NtMITCoreMsgKOpenConnectionTo",
        "NtMITUpdateInputGlobals",
        "NtMITBindInputTypeToMonitors",
        "NtMITEnableMouseIntercept",
        "NtMITDisableMouseIntercept",
        "NtMITSynthesizeTouchInput",
        "NtMITSynthesizeMouseInput",
        "NtMITSynthesizeMouseWheel"
    ]
]