syscalls = [
    [
        "stub_UserGetOwnerTransformedMonitorRect",
        "stub_UserYieldTask",
        "stub_UserSetSensorPresence",
        "NtUserGetThreadState",
        "NtUserPeekMessage",
        "NtUserCallOneParam",
        "NtUserGetKeyState",
        "NtUserInvalidateRect",
        "NtUserCallNoParam",
        "NtUserGetMessage",
        "NtUserMessageCall",
        "NtGdiBitBlt",
        "NtGdiGetCharSet",
        "NtUserGetDC",
        "NtGdiSelectBitmap",
        "NtUserWaitMessage",
        "NtUserTranslateMessage",
        "NtUserGetProp",
        "NtUserPostMessage",
        "NtUserQueryWindow",
        "stub_UserTranslateAccelerator",
        "NtGdiFlush",
        "NtUserRedrawWindow",
        "NtUserWindowFromPoint",
        "NtUserCallMsgFilter",
        "NtUserValidateTimerCallback",
        "NtUserBeginPaint",
        "NtUserSetTimer",
        "NtUserEndPaint",
        "NtUserSetCursor",
        "NtUserKillTimer",
        "NtUserBuildHwndList",
        "NtUserSelectPalette",
        "NtUserCallNextHookEx",
        "NtUserHideCaret",
        "NtGdiIntersectClipRect",
        "NtUserCallHwndLock",
        "NtUserGetProcessWindowStation",
        "NtGdiDeleteObjectApp",
        "NtUserSetWindowPos",
        "NtUserShowCaret",
        "stub_UserEndDeferWindowPosEx",
        "NtUserCallHwndParamLock",
        "NtUserVkKeyScanEx",
        "NtGdiSetDIBitsToDeviceInternal",
        "NtUserCallTwoParam",
        "NtGdiGetRandomRgn",
        "stub_UserCopyAcceleratorTable",
        "NtUserNotifyWinEvent",
        "NtGdiExtSelectClipRgn",
        "NtUserIsClipboardFormatAvailable",
        "NtUserSetScrollInfo",
        "NtGdiStretchBlt",
        "NtUserCreateCaret",
        "NtGdiRectVisible",
        "NtGdiCombineRgn",
        "NtGdiGetDCObject",
        "NtUserDispatchMessage",
        "NtUserRegisterWindowMessage",
        "NtGdiExtTextOutW",
        "NtGdiSelectFont",
        "NtGdiRestoreDC",
        "NtGdiSaveDC",
        "NtUserGetForegroundWindow",
        "stub_UserShowScrollBar",
        "NtUserFindExistingCursorIcon",
        "NtGdiGetDCDword",
        "NtGdiGetRegionData",
        "NtGdiLineTo",
        "NtUserSystemParametersInfo",
        "NtGdiGetAppClipBox",
        "NtUserGetAsyncKeyState",
        "NtUserGetCPD",
        "NtUserRemoveProp",
        "NtGdiDoPalette",
        "NtGdiPolyPolyDraw",
        "NtUserSetCapture",
        "NtUserEnumDisplayMonitors",
        "NtGdiCreateCompatibleBitmap",
        "NtUserSetProp",
        "NtGdiGetTextCharsetInfo",
        "stub_UserSBGetParms",
        "NtUserGetIconInfo",
        "stub_UserExcludeUpdateRgn",
        "NtUserSetFocus",
        "NtGdiExtGetObjectW",
        "NtUserGetUpdateRect",
        "NtGdiCreateCompatibleDC",
        "NtUserGetClipboardSequenceNumber",
        "NtGdiCreatePen",
        "NtUserShowWindow",
        "NtUserGetKeyboardLayoutList",
        "NtGdiPatBlt",
        "NtUserMapVirtualKeyEx",
        "NtUserSetWindowLong",
        "NtGdiHfontCreate",
        "NtUserMoveWindow",
        "NtUserPostThreadMessage",
        "NtUserDrawIconEx",
        "NtUserGetSystemMenu",
        "NtGdiDrawStream",
        "NtUserInternalGetWindowText",
        "NtUserGetWindowDC",
        "stub_GdiD3dDrawPrimitives2",
        "stub_GdiInvertRgn",
        "NtGdiGetRgnBox",
        "NtGdiGetAndSetDCDword",
        "stub_GdiMaskBlt",
        "NtGdiGetWidthTable",
        "NtUserScrollDC",
        "NtUserGetObjectInformation",
        "NtGdiCreateBitmap",
        "NtUserFindWindowEx",
        "NtGdiPolyPatBlt",
        "NtUserUnhookWindowsHookEx",
        "stub_GdiGetNearestColor",
        "NtGdiTransformPoints",
        "NtGdiGetDCPoint",
        "stub_GdiCreateDIBBrush",
        "NtGdiGetTextMetricsW",
        "NtUserCreateWindowEx",
        "NtUserSetParent",
        "NtUserGetKeyboardState",
        "NtUserToUnicodeEx",
        "NtUserGetControlBrush",
        "NtUserGetClassName",
        "NtGdiAlphaBlend",
        "stub_GdiDdBlt",
        "NtGdiOffsetRgn",
        "NtUserDefSetText",
        "NtGdiGetTextFaceW",
        "NtGdiStretchDIBitsInternal",
        "NtUserSendInput",
        "NtUserGetThreadDesktop",
        "NtGdiCreateRectRgn",
        "NtGdiGetDIBitsInternal",
        "stub_UserGetUpdateRgn",
        "NtGdiDeleteClientObj",
        "NtUserGetIconSize",
        "NtUserFillWindow",
        "NtGdiExtCreateRegion",
        "NtGdiComputeXformCoefficients",
        "NtUserSetWindowsHookEx",
        "stub_UserNotifyProcessCreate",
        "stub_GdiUnrealizeObject",
        "NtUserGetTitleBarInfo",
        "NtGdiRectangle",
        "NtUserSetThreadDesktop",
        "NtUserGetDCEx",
        "stub_UserGetScrollBarInfo",
        "stub_GdiGetTextExtent",
        "NtUserSetWindowFNID",
        "NtGdiSetLayout",
        "NtUserCalcMenuBar",
        "NtUserThunkedMenuItemInfo",
        "NtGdiExcludeClipRect",
        "NtGdiCreateDIBSection",
        "NtGdiGetDCforBitmap",
        "NtUserDestroyCursor",
        "NtUserDestroyWindow",
        "NtUserCallHwndParam",
        "NtGdiCreateDIBitmapInternal",
        "stub_UserOpenWindowStation",
        "stub_GdiDdDeleteSurfaceObject",
        "stub_GdiDdCanCreateSurface",
        "stub_GdiDdCreateSurface",
        "NtUserSetCursorIconData",
        "stub_GdiDdDestroySurface",
        "NtUserCloseDesktop",
        "NtUserOpenDesktop",
        "stub_UserSetProcessWindowStation",
        "NtUserGetAtomName",
        "stub_GdiDdResetVisrgn",
        "NtGdiExtCreatePen",
        "NtGdiCreatePaletteInternal",
        "stub_GdiSetBrushOrg",
        "NtUserBuildNameList",
        "NtGdiSetPixel",
        "NtUserRegisterClassExWOW",
        "NtGdiCreatePatternBrushInternal",
        "NtUserGetAncestor",
        "NtGdiGetOutlineTextMetricsInternalW",
        "NtGdiSetBitmapBits",
        "NtUserCloseWindowStation",
        "NtUserGetDoubleClickTime",
        "stub_UserEnableScrollBar",
        "NtGdiCreateSolidBrush",
        "NtUserGetClassInfoEx",
        "NtGdiCreateClientObj",
        "NtUserUnregisterClass",
        "NtUserDeleteMenu",
        "NtGdiRectInRegion",
        "stub_UserScrollWindowEx",
        "NtGdiGetPixel",
        "NtUserSetClassLong",
        "NtUserGetMenuBarInfo",
        "stub_GdiDdCreateSurfaceEx",
        "stub_GdiDdCreateSurfaceObject",
        "stub_GdiGetNearestPaletteIndex",
        "stub_GdiDdLockD3D",
        "stub_GdiDdUnlockD3D",
        "NtGdiGetCharWidthW",
        "stub_UserInvalidateRgn",
        "stub_UserGetClipboardOwner",
        "NtUserSetWindowRgn",
        "NtUserBitBltSysBmp",
        "stub_GdiGetCharWidthInfo",
        "NtUserValidateRect",
        "NtUserCloseClipboard",
        "NtUserOpenClipboard",
        "stub_UserSetClipboardData",
        "NtUserEnableMenuItem",
        "NtUserAlterWindowStyle",
        "NtGdiFillRgn",
        "NtUserGetWindowPlacement",
        "NtGdiModifyWorldTransform",
        "NtGdiGetFontData",
        "NtUserGetOpenClipboardWindow",
        "NtUserSetThreadState",
        "NtGdiOpenDCW",
        "NtUserTrackMouseEvent",
        "NtGdiGetTransform",
        "NtUserDestroyMenu",
        "NtGdiGetBitmapBits",
        "stub_UserConsoleControl",
        "NtUserSetActiveWindow",
        "stub_UserSetInformationThread",
        "stub_UserSetWindowPlacement",
        "NtUserGetControlColor",
        "NtGdiSetMetaRgn",
        "stub_GdiSetMiterLimit",
        "stub_GdiSetVirtualResolution",
        "stub_GdiGetRasterizerCaps",
        "stub_UserSetWindowWord",
        "NtUserGetClipboardFormatName",
        "NtUserRealInternalGetMessage",
        "stub_UserCreateLocalMemHandle",
        "NtUserAttachThreadInput",
        "NtGdiCreateHalftonePalette",
        "stub_UserPaintMenuBar",
        "NtUserSetKeyboardState",
        "stub_GdiCombineTransform",
        "NtUserCreateAcceleratorTable",
        "NtUserGetCursorFrameInfo",
        "stub_UserGetAltTabInfo",
        "NtUserGetCaretBlinkTime",
        "NtGdiQueryFontAssocInfo",
        "stub_UserProcessConnect",
        "NtUserEnumDisplayDevices",
        "stub_UserEmptyClipboard",
        "NtUserGetClipboardData",
        "NtUserRemoveMenu",
        "NtGdiSetBoundsRect",
        "stub_GdiGetBitmapDimension",
        "stub_UserConvertMemHandle",
        "NtUserDestroyAcceleratorTable",
        "NtUserGetGUIThreadInfo",
        "stub_GdiCloseFigure",
        "stub_UserSetWindowsHookAW",
        "stub_UserSetMenuDefaultItem",
        "NtUserCheckMenuItem",
        "NtUserSetWinEventHook",
        "NtUserUnhookWinEvent",
        "stub_UserLockWindowUpdate",
        "stub_UserSetSystemMenu",
        "NtUserThunkedMenuInfo",
        "NtGdiBeginPath",
        "NtGdiEndPath",
        "NtGdiFillPath",
        "NtUserCallHwnd",
        "stub_UserDdeInitialize",
        "NtUserModifyUserStartupInfoFlags",
        "NtUserCountClipboardFormats",
        "stub_GdiAddFontMemResourceEx",
        "stub_GdiEqualRgn",
        "stub_GdiGetSystemPaletteUse",
        "stub_GdiRemoveFontMemResourceEx",
        "NtUserEnumDisplaySettings",
        "stub_UserPaintDesktop",
        "stub_GdiExtEscape",
        "stub_GdiSetBitmapDimension",
        "stub_GdiSetFontEnumeration",
        "NtUserChangeClipboardChain",
        "NtUserSetClipboardViewer",
        "stub_UserShowWindowAsync",
        "stub_GdiCreateColorSpace",
        "stub_GdiDeleteColorSpace",
        "NtUserActivateKeyboardLayout",
        "NtBindCompositionSurface",
        "stub_CompositionInputThread",
        "NtCompositionSetDropTarget",
        "NtCreateCompositionInputSink",
        "NtCreateCompositionSurfaceHandle",
        "stub_CreateImplicitCompositionInputSink",
        "NtDCompositionAddCrossDeviceVisualChild",
        "stub_DCompositionBeginFrame",
        "NtDCompositionCommitChannel",
        "stub_DCompositionConfirmFrame",
        "stub_DCompositionConnectPipe",
        "NtDCompositionCreateAndBindSharedSection",
        "NtDCompositionCreateChannel",
        "stub_DCompositionCreateConnection",
        "stub_DCompositionCreateDwmChannel",
        "NtDCompositionCurrentBatchId",
        "NtDCompositionDestroyChannel",
        "stub_DCompositionDestroyConnection",
        "stub_DCompositionDiscardFrame",
        "stub_DCompositionDuplicateHandleToProcess",
        "stub_DCompositionDuplicateSwapchainHandleToDwm",
        "stub_DCompositionEnableDDASupport",
        "stub_DCompositionEnableMMCSS",
        "stub_DCompositionGetChannels",
        "stub_DCompositionGetConnectionBatch",
        "NtDCompositionGetDeletedResources",
        "stub_DCompositionGetFrameLegacyTokens",
        "NtDCompositionGetFrameStatistics",
        "stub_DCompositionGetFrameSurfaceUpdates",
        "NtDCompositionProcessChannelBatchBuffer",
        "stub_DCompositionReferenceSharedResourceOnDwmChannel",
        "stub_DCompositionRegisterThumbnailVisual",
        "stub_DCompositionRegisterVirtualDesktopVisual",
        "NtDCompositionReleaseAllResources",
        "NtDCompositionRemoveCrossDeviceVisualChild",
        "stub_DCompositionRetireFrame",
        "NtDCompositionSetChannelCallbackId",
        "NtDCompositionSetChannelCommitCompletionEvent",
        "stub_DCompositionSetDebugCounter",
        "stub_DCompositionSubmitDWMBatch",
        "NtDCompositionSynchronize",
        "NtDCompositionTelemetryAnimationScenarioBegin",
        "NtDCompositionTelemetryAnimationScenarioReference",
        "NtDCompositionTelemetryAnimationScenarioUnreference",
        "NtDCompositionTelemetrySetApplicationId",
        "NtDCompositionTelemetryTouchInteractionBegin",
        "NtDCompositionTelemetryTouchInteractionEnd",
        "NtDCompositionTelemetryTouchInteractionUpdate",
        "stub_DCompositionUpdatePointerCapture",
        "NtDCompositionWaitForChannel",
        "stub_DesktopCaptureBits",
        "stub_DuplicateCompositionInputSink",
        "stub_GdiAbortDoc",
        "stub_GdiAbortPath",
        "stub_GdiAddEmbFontToDC",
        "stub_GdiAddFontResourceW",
        "stub_GdiAddRemoteFontToDC",
        "stub_GdiAddRemoteMMInstanceToDC",
        "stub_GdiAngleArc",
        "NtGdiAnyLinkedFonts",
        "stub_GdiArcInternal",
        "stub_GdiBRUSHOBJ_DeleteRbrush",
        "stub_GdiBRUSHOBJ_hGetColorTransform",
        "stub_GdiBRUSHOBJ_pvAllocRbrush",
        "stub_GdiBRUSHOBJ_pvGetRbrush",
        "stub_GdiBRUSHOBJ_ulGetBrushColor",
        "NtGdiBeginGdiRendering",
        "stub_GdiCLIPOBJ_bEnum",
        "stub_GdiCLIPOBJ_cEnumStart",
        "stub_GdiCLIPOBJ_ppoGetPath",
        "stub_GdiCancelDC",
        "stub_GdiChangeGhostFont",
        "stub_GdiCheckBitmapBits",
        "stub_GdiClearBitmapAttributes",
        "stub_GdiClearBrushAttributes",
        "stub_GdiColorCorrectPalette",
        "NtGdiConfigureOPMProtectedOutput",
        "stub_GdiConvertMetafileRect",
        "stub_GdiCreateBitmapFromDxSurface",
        "NtGdiCreateBitmapFromDxSurface2",
        "stub_GdiCreateColorTransform",
        "stub_GdiCreateEllipticRgn",
        "stub_GdiCreateHatchBrushInternal",
        "stub_GdiCreateMetafileDC",
        "NtGdiCreateOPMProtectedOutput",
        "NtGdiCreateOPMProtectedOutputs",
        "NtGdiCreateRoundRectRgn",
        "stub_GdiCreateServerMetaFile",
        "stub_GdiCreateSessionMappedDIBSection",
        "stub_GdiD3dContextCreate",
        "stub_GdiD3dContextDestroy",
        "stub_GdiD3dContextDestroyAll",
        "stub_GdiD3dValidateTextureStageState",
        "stub_GdiDDCCIGetCapabilitiesString",
        "stub_GdiDDCCIGetCapabilitiesStringLength",
        "stub_GdiDDCCIGetTimingReport",
        "stub_GdiDDCCIGetVCPFeature",
        "stub_GdiDDCCISaveCurrentSettings",
        "stub_GdiDDCCISetVCPFeature",
        "stub_GdiDdAddAttachedSurface",
        "stub_GdiDdAlphaBlt",
        "stub_GdiDdAttachSurface",
        "stub_GdiDdBeginMoCompFrame",
        "stub_GdiDdCanCreateD3DBuffer",
        "stub_GdiDdColorControl",
        "stub_GdiDdCreateD3DBuffer",
        "stub_GdiDdCreateDirectDrawObject",
        "stub_GdiDdCreateFullscreenSprite",
        "stub_GdiDdCreateMoComp",
        "stub_GdiDdDDIAbandonSwapChain",
        "stub_GdiDdDDIAcquireKeyedMutex",
        "NtGdiDdDDIAcquireKeyedMutex2",
        "stub_GdiDdDDIAcquireSwapChain",
        "stub_GdiDdDDIAdjustFullscreenGamma",
        "NtGdiDdDDICacheHybridQueryValue",
        "stub_GdiDdDDIChangeVideoMemoryReservation",
        "stub_GdiDdDDICheckExclusiveOwnership",
        "stub_GdiDdDDICheckMonitorPowerState",
        "stub_GdiDdDDICheckMultiPlaneOverlaySupport",
        "stub_GdiDdDDICheckMultiPlaneOverlaySupport2",
        "stub_GdiDdDDICheckMultiPlaneOverlaySupport3",
        "stub_GdiDdDDICheckOcclusion",
        "stub_GdiDdDDICheckSharedResourceAccess",
        "stub_GdiDdDDICheckVidPnExclusiveOwnership",
        "NtGdiDdDDICloseAdapter",
        "NtGdiDdDDIConfigureSharedResource",
        "NtGdiDdDDICreateAllocation",
        "NtGdiDdDDICreateContext",
        "NtGdiDdDDICreateContextVirtual",
        "NtGdiDdDDICreateDCFromMemory",
        "NtGdiDdDDICreateDevice",
        "stub_GdiDdDDICreateKeyedMutex",
        "NtGdiDdDDICreateKeyedMutex2",
        "stub_GdiDdDDICreateOutputDupl",
        "stub_GdiDdDDICreateOverlay",
        "NtGdiDdDDICreatePagingQueue",
        "stub_GdiDdDDICreateSwapChain",
        "NtGdiDdDDICreateSynchronizationObject",
        "NtGdiDdDDIDestroyAllocation",
        "NtGdiDdDDIDestroyAllocation2",
        "NtGdiDdDDIDestroyContext",
        "NtGdiDdDDIDestroyDCFromMemory",
        "NtGdiDdDDIDestroyDevice",
        "NtGdiDdDDIDestroyKeyedMutex",
        "stub_GdiDdDDIDestroyOutputDupl",
        "stub_GdiDdDDIDestroyOverlay",
        "NtGdiDdDDIDestroyPagingQueue",
        "NtGdiDdDDIDestroySynchronizationObject",
        "NtGdiDdDDIEnumAdapters",
        "NtGdiDdDDIEnumAdapters2",
        "NtGdiDdDDIEscape",
        "NtGdiDdDDIEvict",
        "stub_GdiDdDDIFlipOverlay",
        "NtGdiDdDDIFlushHeapTransitions",
        "NtGdiDdDDIFreeGpuVirtualAddress",
        "NtGdiDdDDIGetCachedHybridQueryValue",
        "stub_GdiDdDDIGetContextInProcessSchedulingPriority",
        "NtGdiDdDDIGetContextSchedulingPriority",
        "stub_GdiDdDDIGetDWMVerticalBlankEvent",
        "NtGdiDdDDIGetDeviceState",
        "NtGdiDdDDIGetDisplayModeList",
        "stub_GdiDdDDIGetMultisampleMethodList",
        "stub_GdiDdDDIGetOverlayState",
        "stub_GdiDdDDIGetPresentHistory",
        "stub_GdiDdDDIGetPresentQueueEvent",
        "stub_GdiDdDDIGetProcessSchedulingPriorityClass",
        "stub_GdiDdDDIGetResourcePresentPrivateDriverData",
        "stub_GdiDdDDIGetRuntimeData",
        "stub_GdiDdDDIGetScanLine",
        "stub_GdiDdDDIGetSetSwapChainMetadata",
        "NtGdiDdDDIGetSharedPrimaryHandle",
        "stub_GdiDdDDIGetSharedResourceAdapterLuid",
        "stub_GdiDdDDIInvalidateActiveVidPn",
        "stub_GdiDdDDIInvalidateCache",
        "NtGdiDdDDILock",
        "NtGdiDdDDILock2",
        "NtGdiDdDDIMakeResident",
        "NtGdiDdDDIMapGpuVirtualAddress",
        "NtGdiDdDDIMarkDeviceAsError",
        "stub_GdiDdDDINetDispGetNextChunkInfo",
        "stub_GdiDdDDINetDispQueryMiracastDisplayDeviceStatus",
        "NtGdiDdDDINetDispQueryMiracastDisplayDeviceSupport",
        "stub_GdiDdDDINetDispStartMiracastDisplayDevice",
        "stub_GdiDdDDINetDispStopMiracastDisplayDevice",
        "stub_GdiDdDDINetDispStopSessions",
        "NtGdiDdDDIOfferAllocations",
        "NtGdiDdDDIOpenAdapterFromDeviceName",
        "NtGdiDdDDIOpenAdapterFromHdc",
        "NtGdiDdDDIOpenAdapterFromLuid",
        "stub_GdiDdDDIOpenKeyedMutex",
        "NtGdiDdDDIOpenKeyedMutex2",
        "stub_GdiDdDDIOpenNtHandleFromName",
        "NtGdiDdDDIOpenResource",
        "NtGdiDdDDIOpenResourceFromNtHandle",
        "stub_GdiDdDDIOpenSwapChain",
        "NtGdiDdDDIOpenSyncObjectFromNtHandle",
        "stub_GdiDdDDIOpenSyncObjectFromNtHandle2",
        "stub_GdiDdDDIOpenSyncObjectNtHandleFromName",
        "NtGdiDdDDIOpenSynchronizationObject",
        "stub_GdiDdDDIOutputDuplGetFrameInfo",
        "stub_GdiDdDDIOutputDuplGetMetaData",
        "stub_GdiDdDDIOutputDuplGetPointerShapeData",
        "stub_GdiDdDDIOutputDuplPresent",
        "stub_GdiDdDDIOutputDuplReleaseFrame",
        "stub_GdiDdDDIPinDirectFlipResources",
        "NtGdiDdDDIPollDisplayChildren",
        "NtGdiDdDDIPresent",
        "stub_GdiDdDDIPresentMultiPlaneOverlay",
        "stub_GdiDdDDIPresentMultiPlaneOverlay2",
        "stub_GdiDdDDIPresentMultiPlaneOverlay3",
        "NtGdiDdDDIQueryAdapterInfo",
        "stub_GdiDdDDIQueryAllocationResidency",
        "stub_GdiDdDDIQueryClockCalibration",
        "stub_GdiDdDDIQueryFSEBlock",
        "stub_GdiDdDDIQueryProcessOfferInfo",
        "stub_GdiDdDDIQueryRemoteVidPnSourceFromGdiDisplayName",
        "NtGdiDdDDIQueryResourceInfo",
        "NtGdiDdDDIQueryResourceInfoFromNtHandle",
        "stub_GdiDdDDIQueryStatistics",
        "stub_GdiDdDDIQueryVidPnExclusiveOwnership",
        "NtGdiDdDDIQueryVideoMemoryInfo",
        "NtGdiDdDDIReclaimAllocations",
        "NtGdiDdDDIReclaimAllocations2",
        "stub_GdiDdDDIReleaseKeyedMutex",
        "NtGdiDdDDIReleaseKeyedMutex2",
        "stub_GdiDdDDIReleaseProcessVidPnSourceOwners",
        "stub_GdiDdDDIReleaseSwapChain",
        "NtGdiDdDDIRender",
        "NtGdiDdDDIReserveGpuVirtualAddress",
        "NtGdiDdDDISetAllocationPriority",
        "stub_GdiDdDDISetContextInProcessSchedulingPriority",
        "NtGdiDdDDISetContextSchedulingPriority",
        "stub_GdiDdDDISetDisplayMode",
        "stub_GdiDdDDISetDisplayPrivateDriverFormat",
        "stub_GdiDdDDISetDodIndirectSwapchain",
        "stub_GdiDdDDISetFSEBlock",
        "stub_GdiDdDDISetGammaRamp",
        "NtGdiDdDDISetHwProtectionTeardownRecovery",
        "stub_GdiDdDDISetProcessSchedulingPriorityClass",
        "NtGdiDdDDISetQueuedLimit",
        "stub_GdiDdDDISetStablePowerState",
        "stub_GdiDdDDISetStereoEnabled",
        "stub_GdiDdDDISetSyncRefreshCountWaitTarget",
        "stub_GdiDdDDISetVidPnSourceHwProtection",
        "stub_GdiDdDDISetVidPnSourceOwner",
        "stub_GdiDdDDISetVidPnSourceOwner1",
        "NtGdiDdDDIShareObjects",
        "stub_GdiDdDDISharedPrimaryLockNotification",
        "stub_GdiDdDDISharedPrimaryUnLockNotification",
        "NtGdiDdDDISignalSynchronizationObject",
        "stub_GdiDdDDISignalSynchronizationObjectFromCpu",
        "NtGdiDdDDISignalSynchronizationObjectFromGpu",
        "NtGdiDdDDISignalSynchronizationObjectFromGpu2",
        "NtGdiDdDDISubmitCommand",
        "stub_GdiDdDDITrimProcessCommitment",
        "NtGdiDdDDIUnlock",
        "NtGdiDdDDIUnlock2",
        "stub_GdiDdDDIUnpinDirectFlipResources",
        "stub_GdiDdDDIUpdateAllocationProperty",
        "stub_GdiDdDDIUpdateGpuVirtualAddress",
        "stub_GdiDdDDIUpdateOverlay",
        "stub_GdiDdDDIWaitForIdle",
        "NtGdiDdDDIWaitForSynchronizationObject",
        "NtGdiDdDDIWaitForSynchronizationObjectFromCpu",
        "NtGdiDdDDIWaitForSynchronizationObjectFromGpu",
        "NtGdiDdDDIWaitForVerticalBlankEvent",
        "stub_GdiDdDDIWaitForVerticalBlankEvent2",
        "stub_GdiDdDeleteDirectDrawObject",
        "stub_GdiDdDestroyD3DBuffer",
        "stub_GdiDdDestroyFullscreenSprite",
        "stub_GdiDdDestroyMoComp",
        "stub_GdiDdEndMoCompFrame",
        "stub_GdiDdFlip",
        "stub_GdiDdFlipToGDISurface",
        "stub_GdiDdGetAvailDriverMemory",
        "stub_GdiDdGetBltStatus",
        "stub_GdiDdGetDC",
        "stub_GdiDdGetDriverInfo",
        "stub_GdiDdGetDriverState",
        "stub_GdiDdGetDxHandle",
        "stub_GdiDdGetFlipStatus",
        "stub_GdiDdGetInternalMoCompInfo",
        "stub_GdiDdGetMoCompBuffInfo",
        "stub_GdiDdGetMoCompFormats",
        "stub_GdiDdGetMoCompGuids",
        "stub_GdiDdGetScanLine",
        "stub_GdiDdLock",
        "stub_GdiDdNotifyFullscreenSpriteUpdate",
        "stub_GdiDdQueryDirectDrawObject",
        "stub_GdiDdQueryMoCompStatus",
        "stub_GdiDdQueryVisRgnUniqueness",
        "stub_GdiDdReenableDirectDrawObject",
        "stub_GdiDdReleaseDC",
        "stub_GdiDdRenderMoComp",
        "stub_GdiDdSetColorKey",
        "stub_GdiDdSetExclusiveMode",
        "stub_GdiDdSetGammaRamp",
        "stub_GdiDdSetOverlayPosition",
        "stub_GdiDdUnattachSurface",
        "stub_GdiDdUnlock",
        "stub_GdiDdUpdateOverlay",
        "stub_GdiDdWaitForVerticalBlank",
        "stub_GdiDeleteColorTransform",
        "stub_GdiDescribePixelFormat",
        "NtGdiDestroyOPMProtectedOutput",
        "stub_GdiDestroyPhysicalMonitor",
        "stub_GdiDoBanding",
        "stub_GdiDrawEscape",
        "stub_GdiDvpAcquireNotification",
        "stub_GdiDvpCanCreateVideoPort",
        "stub_GdiDvpColorControl",
        "stub_GdiDvpCreateVideoPort",
        "stub_GdiDvpDestroyVideoPort",
        "stub_GdiDvpFlipVideoPort",
        "stub_GdiDvpGetVideoPortBandwidth",
        "stub_GdiDvpGetVideoPortConnectInfo",
        "stub_GdiDvpGetVideoPortField",
        "stub_GdiDvpGetVideoPortFlipStatus",
        "stub_GdiDvpGetVideoPortInputFormats",
        "stub_GdiDvpGetVideoPortLine",
        "stub_GdiDvpGetVideoPortOutputFormats",
        "stub_GdiDvpGetVideoSignalStatus",
        "stub_GdiDvpReleaseNotification",
        "stub_GdiDvpUpdateVideoPort",
        "stub_GdiDvpWaitForVideoPortSync",
        "stub_GdiDwmCreatedBitmapRemotingOutput",
        "stub_GdiDxgGenericThunk",
        "NtGdiEllipse",
        "stub_GdiEnableEudc",
        "stub_GdiEndDoc",
        "NtGdiEndGdiRendering",
        "stub_GdiEndPage",
        "stub_GdiEngAlphaBlend",
        "stub_GdiEngAssociateSurface",
        "stub_GdiEngBitBlt",
        "stub_GdiEngCheckAbort",
        "stub_GdiEngComputeGlyphSet",
        "stub_GdiEngCopyBits",
        "stub_GdiEngCreateBitmap",
        "stub_GdiEngCreateClip",
        "stub_GdiEngCreateDeviceBitmap",
        "stub_GdiEngCreateDeviceSurface",
        "stub_GdiEngCreatePalette",
        "stub_GdiEngDeleteClip",
        "stub_GdiEngDeletePalette",
        "stub_GdiEngDeletePath",
        "stub_GdiEngDeleteSurface",
        "stub_GdiEngEraseSurface",
        "stub_GdiEngFillPath",
        "stub_GdiEngGradientFill",
        "stub_GdiEngLineTo",
        "stub_GdiEngLockSurface",
        "stub_GdiEngMarkBandingSurface",
        "stub_GdiEngPaint",
        "stub_GdiEngPlgBlt",
        "stub_GdiEngStretchBlt",
        "stub_GdiEngStretchBltROP",
        "stub_GdiEngStrokeAndFillPath",
        "stub_GdiEngStrokePath",
        "stub_GdiEngTextOut",
        "stub_GdiEngTransparentBlt",
        "stub_GdiEngUnlockSurface",
        "NtGdiEnumFonts",
        "stub_GdiEnumObjects",
        "stub_GdiEudcLoadUnloadLink",
        "stub_GdiExtFloodFill",
        "stub_GdiFONTOBJ_cGetAllGlyphHandles",
        "stub_GdiFONTOBJ_cGetGlyphs",
        "stub_GdiFONTOBJ_pQueryGlyphAttrs",
        "stub_GdiFONTOBJ_pfdg",
        "stub_GdiFONTOBJ_pifi",
        "stub_GdiFONTOBJ_pvTrueTypeFontFile",
        "stub_GdiFONTOBJ_pxoGetXform",
        "stub_GdiFONTOBJ_vGetInfo",
        "stub_GdiFlattenPath",
        "NtGdiFontIsLinked",
        "stub_GdiForceUFIMapping",
        "NtGdiFrameRgn",
        "stub_GdiFullscreenControl",
        "NtGdiGetBoundsRect",
        "stub_GdiGetCOPPCompatibleOPMInformation",
        "stub_GdiGetCertificate",
        "NtGdiGetCertificateByHandle",
        "stub_GdiGetCertificateSize",
        "NtGdiGetCertificateSizeByHandle",
        "NtGdiGetCharABCWidthsW",
        "stub_GdiGetCharacterPlacementW",
        "stub_GdiGetColorAdjustment",
        "stub_GdiGetColorSpaceforBitmap",
        "NtGdiGetCurrentDpiInfo",
        "NtGdiGetDeviceCaps",
        "stub_GdiGetDeviceCapsAll",
        "stub_GdiGetDeviceGammaRamp",
        "NtGdiGetDeviceWidth",
        "stub_GdiGetDhpdev",
        "stub_GdiGetETM",
        "stub_GdiGetEmbUFI",
        "stub_GdiGetEmbedFonts",
        "NtGdiGetEntry",
        "stub_GdiGetEudcTimeStampEx",
        "stub_GdiGetFontFileData",
        "stub_GdiGetFontFileInfo",
        "stub_GdiGetFontResourceInfoInternalW",
        "stub_GdiGetFontUnicodeRanges",
        "NtGdiGetGlyphIndicesW",
        "stub_GdiGetGlyphIndicesWInternal",
        "stub_GdiGetGlyphOutline",
        "stub_GdiGetKerningPairs",
        "stub_GdiGetLinkedUFIs",
        "stub_GdiGetMiterLimit",
        "NtGdiGetMonitorID",
        "NtGdiGetNumberOfPhysicalMonitors",
        "NtGdiGetOPMInformation",
        "NtGdiGetOPMRandomNumber",
        "stub_GdiGetObjectBitmapHandle",
        "stub_GdiGetPath",
        "stub_GdiGetPerBandInfo",
        "stub_GdiGetPhysicalMonitorDescription",
        "stub_GdiGetPhysicalMonitors",
        "stub_GdiGetProcessSessionFonts",
        "stub_GdiGetPublicFontTableChangeCookie",
        "NtGdiGetRealizationInfo",
        "stub_GdiGetServerMetaFileBits",
        "stub_GdiGetSpoolMessage",
        "stub_GdiGetStats",
        "stub_GdiGetStringBitmapW",
        "NtGdiGetSuggestedOPMProtectedOutputArraySize",
        "NtGdiGetTextExtentExW",
        "stub_GdiGetUFI",
        "stub_GdiGetUFIPathname",
        "NtGdiGradientFill",
        "stub_GdiHLSurfGetInformation",
        "stub_GdiHLSurfSetInformation",
        "stub_GdiHT_Get8BPPFormatPalette",
        "stub_GdiHT_Get8BPPMaskPalette",
        "stub_GdiIcmBrushInfo",
        "NtGdiInit",
        "stub_GdiInitSpool",
        "stub_GdiMakeFontDir",
        "stub_GdiMakeInfoDC",
        "stub_GdiMakeObjectUnXferable",
        "stub_GdiMakeObjectXferable",
        "stub_GdiMirrorWindowOrg",
        "stub_GdiMonoBitmap",
        "stub_GdiMoveTo",
        "stub_GdiOffsetClipRgn",
        "stub_GdiPATHOBJ_bEnum",
        "stub_GdiPATHOBJ_bEnumClipLines",
        "stub_GdiPATHOBJ_vEnumStart",
        "stub_GdiPATHOBJ_vEnumStartClipLines",
        "stub_GdiPATHOBJ_vGetBounds",
        "stub_GdiPathToRegion",
        "stub_GdiPlgBlt",
        "stub_GdiPolyDraw",
        "stub_GdiPolyTextOutW",
        "stub_GdiPtInRegion",
        "stub_GdiPtVisible",
        "stub_GdiQueryFonts",
        "stub_GdiRemoveFontResourceW",
        "stub_GdiRemoveMergeFont",
        "stub_GdiResetDC",
        "stub_GdiResizePalette",
        "NtGdiRoundRect",
        "stub_GdiSTROBJ_bEnum",
        "stub_GdiSTROBJ_bEnumPositionsOnly",
        "stub_GdiSTROBJ_bGetAdvanceWidths",
        "stub_GdiSTROBJ_dwGetCodePage",
        "stub_GdiSTROBJ_vEnumStart",
        "stub_GdiScaleViewportExtEx",
        "stub_GdiScaleWindowExtEx",
        "stub_GdiSelectBrush",
        "NtGdiSelectClipPath",
        "stub_GdiSelectPen",
        "stub_GdiSetBitmapAttributes",
        "stub_GdiSetBrushAttributes",
        "stub_GdiSetColorAdjustment",
        "stub_GdiSetColorSpace",
        "stub_GdiSetDeviceGammaRamp",
        "stub_GdiSetFontXform",
        "NtGdiSetIcmMode",
        "stub_GdiSetLinkedUFIs",
        "stub_GdiSetMagicColors",
        "NtGdiSetOPMSigningKeyAndSequenceNumbers",
        "stub_GdiSetPUMPDOBJ",
        "stub_GdiSetPixelFormat",
        "stub_GdiSetRectRgn",
        "stub_GdiSetSizeDevice",
        "stub_GdiSetSystemPaletteUse",
        "stub_GdiSetTextJustification",
        "NtGdiSetUMPDSandboxState",
        "stub_GdiStartDoc",
        "stub_GdiStartPage",
        "stub_GdiStrokeAndFillPath",
        "NtGdiStrokePath",
        "stub_GdiSwapBuffers",
        "NtGdiTransparentBlt",
        "stub_GdiUMPDEngFreeUserMem",
        "stub_GdiUnloadPrinterDriver",
        "stub_GdiUnmapMemFont",
        "stub_GdiUpdateColors",
        "stub_GdiUpdateTransform",
        "stub_GdiWidenPath",
        "stub_GdiXFORMOBJ_bApplyXform",
        "stub_GdiXFORMOBJ_iGetXform",
        "stub_GdiXLATEOBJ_cGetPalette",
        "stub_GdiXLATEOBJ_hGetColorTransform",
        "stub_GdiXLATEOBJ_iXlate",
        "stub_HWCursorUpdatePointer",
        "stub_NotifyPresentToCompositionSurface",
        "stub_OpenCompositionSurfaceDirtyRegion",
        "stub_OpenCompositionSurfaceSectionInfo",
        "stub_OpenCompositionSurfaceSwapChainHandleInfo",
        "stub_QueryCompositionInputIsImplicit",
        "stub_QueryCompositionInputQueueAndTransform",
        "stub_QueryCompositionInputSink",
        "stub_QueryCompositionInputSinkLuid",
        "stub_QueryCompositionInputSinkViewId",
        "stub_QueryCompositionSurfaceBinding",
        "stub_QueryCompositionSurfaceHDRMetaData",
        "stub_QueryCompositionSurfaceRenderingRealization",
        "NtQueryCompositionSurfaceStatistics",
        "stub_RIMAddInputObserver",
        "stub_RIMGetDevicePreparsedDataLockfree",
        "stub_RIMObserveNextInput",
        "stub_RIMRemoveInputObserver",
        "stub_RIMUpdateInputObserverRegistration",
        "stub_SetCompositionSurfaceAnalogExclusive",
        "stub_SetCompositionSurfaceBufferCompositionModeAndOrientation",
        "stub_SetCompositionSurfaceDirectFlipState",
        "stub_SetCompositionSurfaceHDRMetaData",
        "stub_SetCompositionSurfaceIndependentFlipInfo",
        "stub_SetCompositionSurfaceStatistics",
        "stub_TokenManagerConfirmOutstandingAnalogToken",
        "NtTokenManagerCreateCompositionTokenHandle",
        "stub_TokenManagerGetAnalogExclusiveSurfaceUpdates",
        "stub_TokenManagerGetAnalogExclusiveTokenEvent",
        "stub_TokenManagerOpenSectionAndEvents",
        "stub_TokenManagerThread",
        "NtUnBindCompositionSurface",
        "stub_UpdateInputSinkTransforms",
        "stub_UserAcquireIAMKey",
        "stub_UserAcquireInteractiveControlBackgroundAccess",
        "stub_UserAddClipboardFormatListener",
        "NtUserAssociateInputContext",
        "NtUserAutoPromoteMouseInPointer",
        "stub_UserAutoRotateScreen",
        "stub_UserBlockInput",
        "stub_UserBroadcastThemeChangeEvent",
        "NtUserBuildHimcList",
        "stub_UserBuildPropList",
        "stub_UserCalculatePopupWindowPosition",
        "stub_UserCallHwndOpt",
        "stub_UserCanBrokerForceForeground",
        "stub_UserChangeDisplaySettings",
        "NtUserChangeWindowMessageFilterEx",
        "stub_UserCheckAccessForIntegrityLevel",
        "stub_UserCheckProcessForClipboardAccess",
        "stub_UserCheckProcessSession",
        "stub_UserCheckWindowThreadDesktop",
        "NtUserChildWindowFromPointEx",
        "stub_UserClearForeground",
        "NtUserClipCursor",
        "stub_UserCompositionInputSinkLuidFromPoint",
        "NtUserCreateDCompositionHwndTarget",
        "stub_UserCreateDesktopEx",
        "NtUserCreateInputContext",
        "stub_UserCreateWindowStation",
        "stub_UserCtxDisplayIOCtl",
        "stub_UserDeferWindowPosAndBand",
        "NtUserDelegateCapturePointers",
        "NtUserDelegateInput",
        "NtUserDestroyDCompositionHwndTarget",
        "NtUserDestroyInputContext",
        "stub_UserDisableImmersiveOwner",
        "stub_UserDisableProcessWindowFiltering",
        "NtUserDisableThreadIme",
        "stub_UserDiscardPointerFrameMessages",
        "NtUserDisplayConfigGetDeviceInfo",
        "stub_UserDisplayConfigSetDeviceInfo",
        "stub_UserDoSoundConnect",
        "stub_UserDoSoundDisconnect",
        "stub_UserDragDetect",
        "stub_UserDragObject",
        "stub_UserDrawAnimatedRects",
        "stub_UserDrawCaption",
        "stub_UserDrawCaptionTemp",
        "stub_UserDrawMenuBarTemp",
        "stub_UserDwmGetRemoteSessionOcclusionEvent",
        "stub_UserDwmGetRemoteSessionOcclusionState",
        "stub_UserDwmKernelShutdown",
        "stub_UserDwmKernelStartup",
        "stub_UserDwmValidateWindow",
        "stub_UserEnableChildWindowDpiMessage",
        "stub_UserEnableIAMAccess",
        "NtUserEnableMouseInPointer",
        "stub_UserEnableMouseInputForCursorSuppression",
        "stub_UserEnableNonClientDpiScaling",
        "stub_UserEnableTouchPad",
        "NtUserEndMenu",
        "stub_UserEvent",
        "stub_UserFlashWindowEx",
        "stub_UserFrostCrashedWindow",
        "stub_UserGetAppImeLevel",
        "stub_UserGetAutoRotationState",
        "NtUserGetCIMSSM",
        "NtUserGetCaretPos",
        "stub_UserGetClipCursor",
        "stub_UserGetClipboardAccessToken",
        "stub_UserGetClipboardViewer",
        "stub_UserGetComboBoxInfo",
        "NtUserGetCurrentInputMessageSource",
        "NtUserGetCursorDims",
        "NtUserGetCursorInfo",
        "NtUserGetDManipHookInitFunction",
        "stub_UserGetDesktopID",
        "stub_UserGetDisplayAutoRotationPreferences",
        "stub_UserGetDisplayAutoRotationPreferencesByProcessId",
        "NtUserGetDisplayConfigBufferSizes",
        "NtUserGetDpiForMonitor",
        "NtUserGetGestureConfig",
        "stub_UserGetGestureExtArgs",
        "NtUserGetGestureInfo",
        "stub_UserGetGuiResources",
        "stub_UserGetHimetricScaleFactorFromPixelLocation",
        "NtUserGetImeHotKey",
        "NtUserGetImeInfoEx",
        "stub_UserGetInputLocaleInfo",
        "stub_UserGetInteractiveControlDeviceInfo",
        "stub_UserGetInteractiveControlInfo",
        "stub_UserGetInternalWindowPos",
        "NtUserGetKeyNameText",
        "NtUserGetKeyboardLayoutName",
        "NtUserGetLayeredWindowAttributes",
        "stub_UserGetListBoxInfo",
        "stub_UserGetMenuIndex",
        "NtUserGetMenuItemRect",
        "stub_UserGetMouseMovePointsEx",
        "NtUserGetPhysicalDeviceRect",
        "NtUserGetPointerCursorId",
        "NtUserGetPointerDevice",
        "stub_UserGetPointerDeviceCursors",
        "NtUserGetPointerDeviceProperties",
        "NtUserGetPointerDeviceRects",
        "NtUserGetPointerDevices",
        "NtUserGetPointerFrameArrivalTimes",
        "NtUserGetPointerInfoList",
        "NtUserGetPointerInputTransform",
        "NtUserGetPointerType",
        "NtUserGetPrecisionTouchPadConfiguration",
        "stub_UserGetPriorityClipboardFormat",
        "NtUserGetProcessDpiAwarenessContext",
        "NtUserGetProcessUIContextInformation",
        "NtUserGetQueueStatusReadonly",
        "stub_UserGetRawInputBuffer",
        "NtUserGetRawInputData",
        "NtUserGetRawInputDeviceInfo",
        "NtUserGetRawInputDeviceList",
        "NtUserGetRawPointerDeviceData",
        "stub_UserGetRegisteredRawInputDevices",
        "stub_UserGetTopLevelWindow",
        "NtUserGetTouchInputInfo",
        "stub_UserGetTouchValidationStatus",
        "stub_UserGetUpdatedClipboardFormats",
        "stub_UserGetWOWClass",
        "NtUserGetWindowBand",
        "NtUserGetWindowCompositionAttribute",
        "stub_UserGetWindowCompositionInfo",
        "stub_UserGetWindowDisplayAffinity",
        "NtUserGetWindowFeedbackSetting",
        "stub_UserGetWindowMinimizeRect",
        "stub_UserGetWindowRgnEx",
        "stub_UserGhostWindowFromHungWindow",
        "NtUserHandleDelegatedInput",
        "stub_UserHardErrorControl",
        "NtUserHidePointerContactVisualization",
        "stub_UserHiliteMenuItem",
        "stub_UserHungWindowFromGhostWindow",
        "stub_UserHwndQueryRedirectionInfo",
        "stub_UserHwndSetRedirectionInfo",
        "stub_UserImpersonateDdeClientWindow",
        "stub_UserInheritWindowMonitor",
        "stub_UserInitTask",
        "stub_UserInitialize",
        "stub_UserInitializeClientPfnArrays",
        "stub_UserInitializeInputDeviceInjection",
        "stub_UserInitializePointerDeviceInjection",
        "stub_UserInitializeTouchInjection",
        "stub_UserInjectDeviceInput",
        "stub_UserInjectGesture",
        "stub_UserInjectKeyboardInput",
        "stub_UserInjectMouseInput",
        "stub_UserInjectPointerInput",
        "stub_UserInjectTouchInput",
        "stub_UserInteractiveControlQueryUsage",
        "stub_UserInternalClipCursor",
        "stub_UserInternalGetWindowIcon",
        "NtUserIsChildWindowDpiMessageEnabled",
        "stub_UserIsMouseInPointerEnabled",
        "stub_UserIsMouseInputEnabled",
        "NtUserIsNonClientDpiScalingEnabled",
        "NtUserIsTopLevelWindow",
        "NtUserIsTouchWindow",
        "NtUserIsWindowBroadcastingDpiToChildren",
        "stub_UserLayoutCompleted",
        "NtUserLinkDpiCursor",
        "NtUserLoadKeyboardLayoutEx",
        "stub_UserLockWindowStation",
        "stub_UserLockWorkStation",
        "NtUserLogicalToPerMonitorDPIPhysicalPoint",
        "NtUserLogicalToPhysicalPoint",
        "stub_UserMNDragLeave",
        "stub_UserMNDragOver",
        "stub_UserMagControl",
        "stub_UserMagGetContextInformation",
        "stub_UserMagSetContextInformation",
        "NtUserMenuItemFromPoint",
        "stub_UserMinMaximize",
        "NtUserModifyWindowTouchCapability",
        "stub_UserNavigateFocus",
        "NtUserNotifyIMEStatus",
        "NtUserOpenInputDesktop",
        "stub_UserOpenThreadDesktop",
        "stub_UserPaintMonitor",
        "stub_UserPerMonitorDPIPhysicalToLogicalPoint",
        "NtUserPhysicalToLogicalPoint",
        "stub_UserPrintWindow",
        "stub_UserPromoteMouseInPointer",
        "NtUserPromotePointer",
        "stub_UserQueryBSDRWindow",
        "NtUserQueryDisplayConfig",
        "stub_UserQueryInformationThread",
        "NtUserQueryInputContext",
        "stub_UserQuerySendMessage",
        "stub_UserRealChildWindowFromPoint",
        "stub_UserRealWaitMessageEx",
        "stub_UserRegisterBSDRWindow",
        "stub_UserRegisterDManipHook",
        "stub_UserRegisterEdgy",
        "stub_UserRegisterErrorReportingDialog",
        "NtUserRegisterHotKey",
        "stub_UserRegisterManipulationThread",
        "stub_UserRegisterPointerDeviceNotifications",
        "stub_UserRegisterPointerInputTarget",
        "NtUserRegisterRawInputDevices",
        "stub_UserRegisterServicesProcess",
        "stub_UserRegisterSessionPort",
        "stub_UserRegisterShellPTPListener",
        "stub_UserRegisterTasklist",
        "NtUserRegisterTouchHitTestingWindow",
        "stub_UserRegisterTouchPadCapable",
        "stub_UserRegisterUserApiHook",
        "stub_UserReleaseDwmHitTestWaiters",
        "stub_UserRemoteConnect",
        "stub_UserRemoteRedrawRectangle",
        "stub_UserRemoteRedrawScreen",
        "stub_UserRemoteStopScreenUpdates",
        "stub_UserRemoveClipboardFormatListener",
        "stub_UserRemoveInjectionDevice",
        "NtUserReportInertia",
        "stub_UserResolveDesktopForWOW",
        "stub_UserSendEventMessage",
        "stub_UserSendInteractiveControlHapticsReport",
        "stub_UserSetActivationFilter",
        "stub_UserSetActiveProcessForMonitor",
        "stub_UserSetAppImeLevel",
        "stub_UserSetAutoRotation",
        "stub_UserSetBrokeredForeground",
        "stub_UserSetCalibrationData",
        "stub_UserSetChildWindowNoActivate",
        "stub_UserSetClassWord",
        "stub_UserSetCoreWindow",
        "stub_UserSetCoreWindowPartner",
        "stub_UserSetCursorContents",
        "stub_UserSetDisplayAutoRotationPreferences",
        "stub_UserSetDisplayConfig",
        "stub_UserSetDisplayMapping",
        "stub_UserSetFallbackForeground",
        "stub_UserSetFeatureReportResponse",
        "NtUserSetGestureConfig",
        "NtUserSetImeHotKey",
        "NtUserSetImeInfoEx",
        "NtUserSetImeOwnerWindow",
        "stub_UserSetInteractiveControlFocus",
        "stub_UserSetInteractiveCtrlRotationAngle",
        "stub_UserSetInternalWindowPos",
        "NtUserSetLayeredWindowAttributes",
        "stub_UserSetManipulationInputTarget",
        "stub_UserSetMenu",
        "stub_UserSetMenuContextHelpId",
        "stub_UserSetMenuFlagRtoL",
        "stub_UserSetMirrorRendering",
        "stub_UserSetObjectInformation",
        "stub_UserSetPrecisionTouchPadConfiguration",
        "NtUserSetProcessDpiAwarenessContext",
        "NtUserSetProcessInteractionFlags",
        "stub_UserSetProcessRestrictionExemption",
        "stub_UserSetProcessUIAccessZorder",
        "stub_UserSetShellWindowEx",
        "stub_UserSetSysColors",
        "stub_UserSetSystemCursor",
        "stub_UserSetSystemTimer",
        "NtUserSetThreadInputBlocked",
        "NtUserSetThreadLayoutHandles",
        "stub_UserSetWindowArrangement",
        "stub_UserSetWindowBand",
        "NtUserSetWindowCompositionAttribute",
        "NtUserSetWindowCompositionTransition",
        "stub_UserSetWindowDisplayAffinity",
        "NtUserSetWindowFeedbackSetting",
        "stub_UserSetWindowRgnEx",
        "stub_UserSetWindowShowState",
        "stub_UserSetWindowStationUser",
        "stub_UserShowSystemCursor",
        "stub_UserShutdownBlockReasonCreate",
        "stub_UserShutdownBlockReasonQuery",
        "stub_UserShutdownReasonDestroy",
        "stub_UserSignalRedirectionStartComplete",
        "stub_UserSlicerControl",
        "stub_UserSoundSentry",
        "stub_UserSwitchDesktop",
        "stub_UserSystemParametersInfoForDpi",
        "stub_UserTestForInteractiveUser",
        "NtUserTrackPopupMenuEx",
        "NtUserTransformPoint",
        "NtUserTransformRect",
        "NtUserUndelegateInput",
        "stub_UserUnloadKeyboardLayout",
        "stub_UserUnlockWindowStation",
        "stub_UserUnregisterHotKey",
        "stub_UserUnregisterSessionPort",
        "stub_UserUnregisterUserApiHook",
        "stub_UserUpdateDefaultDesktopThumbnail",
        "NtUserUpdateInputContext",
        "stub_UserUpdateInstance",
        "NtUserUpdateLayeredWindow",
        "stub_UserUpdatePerUserSystemParameters",
        "stub_UserUpdateWindowInputSinkHints",
        "stub_UserUpdateWindowTrackingInfo",
        "stub_UserUpdateWindowTransform",
        "stub_UserUserHandleGrantAccess",
        "stub_UserValidateHandleSecure",
        "stub_UserWaitAvailableMessageEx",
        "stub_UserWaitForInputIdle",
        "stub_UserWaitForMsgAndEvent",
        "stub_UserWaitForRedirectionStartComplete",
        "NtUserWindowFromPhysicalPoint",
        "stub_ValidateCompositionSurfaceHandle",
        "NtVisualCaptureBits",
        "NtUserSetClassLongPtr",
        "NtUserSetWindowLongPtr"
    ],
    [
        "NtAccessCheck",
        "NtWorkerFactoryWorkerReady",
        "NtAcceptConnectPort",
        "NtMapUserPhysicalPagesScatter",
        "NtWaitForSingleObject",
        "NtCallbackReturn",
        "NtReadFile",
        "NtDeviceIoControlFile",
        "NtWriteFile",
        "NtRemoveIoCompletion",
        "NtReleaseSemaphore",
        "NtReplyWaitReceivePort",
        "NtReplyPort",
        "NtSetInformationThread",
        "NtSetEvent",
        "NtClose",
        "NtQueryObject",
        "NtQueryInformationFile",
        "NtOpenKey",
        "NtEnumerateValueKey",
        "NtFindAtom",
        "NtQueryDefaultLocale",
        "NtQueryKey",
        "NtQueryValueKey",
        "NtAllocateVirtualMemory",
        "NtQueryInformationProcess",
        "NtWaitForMultipleObjects32",
        "NtWriteFileGather",
        "NtSetInformationProcess",
        "NtCreateKey",
        "NtFreeVirtualMemory",
        "NtImpersonateClientOfPort",
        "NtReleaseMutant",
        "NtQueryInformationToken",
        "NtRequestWaitReplyPort",
        "NtQueryVirtualMemory",
        "NtOpenThreadToken",
        "NtQueryInformationThread",
        "NtOpenProcess",
        "NtSetInformationFile",
        "NtMapViewOfSection",
        "NtAccessCheckAndAuditAlarm",
        "NtUnmapViewOfSection",
        "NtReplyWaitReceivePortEx",
        "NtTerminateProcess",
        "NtSetEventBoostPriority",
        "NtReadFileScatter",
        "NtOpenThreadTokenEx",
        "NtOpenProcessTokenEx",
        "NtQueryPerformanceCounter",
        "NtEnumerateKey",
        "NtOpenFile",
        "NtDelayExecution",
        "NtQueryDirectoryFile",
        "NtQuerySystemInformation",
        "NtOpenSection",
        "NtQueryTimer",
        "NtFsControlFile",
        "NtWriteVirtualMemory",
        "NtCloseObjectAuditAlarm",
        "NtDuplicateObject",
        "NtQueryAttributesFile",
        "NtClearEvent",
        "NtReadVirtualMemory",
        "NtOpenEvent",
        "NtAdjustPrivilegesToken",
        "NtDuplicateToken",
        "NtContinue",
        "NtQueryDefaultUILanguage",
        "NtQueueApcThread",
        "NtYieldExecution",
        "NtAddAtom",
        "NtCreateEvent",
        "NtQueryVolumeInformationFile",
        "NtCreateSection",
        "NtFlushBuffersFile",
        "NtApphelpCacheControl",
        "NtCreateProcessEx",
        "NtCreateThread",
        "NtIsProcessInJob",
        "NtProtectVirtualMemory",
        "NtQuerySection",
        "NtResumeThread",
        "NtTerminateThread",
        "NtReadRequestData",
        "NtCreateFile",
        "NtQueryEvent",
        "NtWriteRequestData",
        "NtOpenDirectoryObject",
        "NtAccessCheckByTypeAndAuditAlarm",
        "NtQuerySystemTime",
        "NtWaitForMultipleObjects",
        "NtSetInformationObject",
        "NtCancelIoFile",
        "NtTraceEvent",
        "NtPowerInformation",
        "NtSetValueKey",
        "NtCancelTimer",
        "NtSetTimer",
        "NtAccessCheckByType",
        "NtAccessCheckByTypeResultList",
        "NtAccessCheckByTypeResultListAndAuditAlarm",
        "NtAccessCheckByTypeResultListAndAuditAlarmByHandle",
        "NtAddAtomEx",
        "NtAddBootEntry",
        "NtAddDriverEntry",
        "NtAdjustGroupsToken",
        "NtAdjustTokenClaimsAndDeviceGroups",
        "NtAlertResumeThread",
        "NtAlertThread",
        "NtAlertThreadByThreadId",
        "NtAllocateLocallyUniqueId",
        "NtAllocateReserveObject",
        "NtAllocateUserPhysicalPages",
        "NtAllocateUuids",
        "NtAlpcAcceptConnectPort",
        "NtAlpcCancelMessage",
        "NtAlpcConnectPort",
        "NtAlpcConnectPortEx",
        "NtAlpcCreatePort",
        "NtAlpcCreatePortSection",
        "NtAlpcCreateResourceReserve",
        "NtAlpcCreateSectionView",
        "NtAlpcCreateSecurityContext",
        "NtAlpcDeletePortSection",
        "NtAlpcDeleteResourceReserve",
        "NtAlpcDeleteSectionView",
        "NtAlpcDeleteSecurityContext",
        "NtAlpcDisconnectPort",
        "NtAlpcImpersonateClientContainerOfPort",
        "NtAlpcImpersonateClientOfPort",
        "NtAlpcOpenSenderProcess",
        "NtAlpcOpenSenderThread",
        "NtAlpcQueryInformation",
        "NtAlpcQueryInformationMessage",
        "NtAlpcRevokeSecurityContext",
        "NtAlpcSendWaitReceivePort",
        "NtAlpcSetInformation",
        "NtAreMappedFilesTheSame",
        "NtAssignProcessToJobObject",
        "NtAssociateWaitCompletionPacket",
        "NtCancelIoFileEx",
        "NtCancelSynchronousIoFile",
        "NtCancelTimer2",
        "NtCancelWaitCompletionPacket",
        "NtCommitComplete",
        "NtCommitEnlistment",
        "NtCommitRegistryTransaction",
        "NtCommitTransaction",
        "NtCompactKeys",
        "NtCompareObjects",
        "NtCompareTokens",
        "ArbPreprocessEntry",
        "NtCompressKey",
        "NtConnectPort",
        "NtCreateDebugObject",
        "NtCreateDirectoryObject",
        "NtCreateDirectoryObjectEx",
        "NtCreateEnclave",
        "NtCreateEnlistment",
        "NtAdjustTokenClaimsAndDeviceGroups",
        "NtCreateIRTimer",
        "NtCreateIoCompletion",
        "NtCreateJobObject",
        "ArbAddReserved",
        "NtCreateKeyTransacted",
        "NtCreateKeyedEvent",
        "NtCreateLowBoxToken",
        "NtCreateMailslotFile",
        "NtCreateMutant",
        "NtCreateNamedPipeFile",
        "NtCreatePagingFile",
        "NtCreatePartition",
        "NtCreatePort",
        "NtCreatePrivateNamespace",
        "NtCreateProcess",
        "NtCreateProfile",
        "NtCreateProfileEx",
        "NtCreateRegistryTransaction",
        "NtCreateResourceManager",
        "NtCreateSemaphore",
        "NtCreateSymbolicLinkObject",
        "NtCreateThreadEx",
        "NtCreateTimer",
        "NtCreateTimer2",
        "NtCreateToken",
        "NtCreateTokenEx",
        "NtCreateTransaction",
        "NtCreateTransactionManager",
        "NtCreateUserProcess",
        "NtCreateWaitCompletionPacket",
        "NtCreateWaitablePort",
        "NtCreateWnfStateName",
        "NtCreateWorkerFactory",
        "NtDebugActiveProcess",
        "NtDebugContinue",
        "NtDeleteAtom",
        "NtDeleteBootEntry",
        "NtDeleteDriverEntry",
        "NtDeleteFile",
        "NtDeleteKey",
        "NtDeleteObjectAuditAlarm",
        "NtDeletePrivateNamespace",
        "NtDeleteValueKey",
        "NtDeleteWnfStateData",
        "NtDeleteWnfStateName",
        "NtDisableLastKnownGood",
        "NtDisplayString",
        "NtDrawText",
        "NtEnableLastKnownGood",
        "NtEnumerateBootEntries",
        "NtEnumerateDriverEntries",
        "NtEnumerateSystemEnvironmentValuesEx",
        "NtEnumerateTransactionObject",
        "NtExtendSection",
        "NtFilterBootOption",
        "NtFilterToken",
        "NtAdjustTokenClaimsAndDeviceGroups",
        "NtFlushBuffersFileEx",
        "NtFlushInstallUILanguage",
        "ArbPreprocessEntry",
        "NtFlushKey",
        "NtFlushProcessWriteBuffers",
        "NtFlushVirtualMemory",
        "NtFlushWriteBuffer",
        "NtFreeUserPhysicalPages",
        "NtFreezeRegistry",
        "NtFreezeTransactions",
        "NtGetCachedSigningLevel",
        "NtGetCompleteWnfStateSubscription",
        "NtGetContextThread",
        "NtGetCurrentProcessorNumber",
        "NtGetCurrentProcessorNumberEx",
        "NtGetDevicePowerState",
        "NtGetMUIRegistryInfo",
        "NtGetNextProcess",
        "NtGetNextThread",
        "NtGetNlsSectionPtr",
        "NtGetNotificationResourceManager",
        "NtGetWriteWatch",
        "NtImpersonateAnonymousToken",
        "NtImpersonateThread",
        "NtInitializeEnclave",
        "NtInitializeNlsFiles",
        "NtInitializeRegistry",
        "NtInitiatePowerAction",
        "NtIsSystemResumeAutomatic",
        "NtIsUILanguageComitted",
        "NtListenPort",
        "NtLoadDriver",
        "NtLoadEnclaveData",
        "NtLoadKey",
        "NtLoadKey2",
        "NtLoadKeyEx",
        "NtLockFile",
        "NtLockProductActivationKeys",
        "NtLockRegistryKey",
        "NtLockVirtualMemory",
        "NtMakePermanentObject",
        "NtMakeTemporaryObject",
        "NtManagePartition",
        "NtMapCMFModule",
        "NtMapUserPhysicalPages",
        "NtModifyBootEntry",
        "NtModifyDriverEntry",
        "NtNotifyChangeDirectoryFile",
        "NtNotifyChangeKey",
        "NtNotifyChangeMultipleKeys",
        "NtNotifyChangeSession",
        "NtOpenEnlistment",
        "NtAdjustTokenClaimsAndDeviceGroups",
        "NtOpenIoCompletion",
        "NtOpenJobObject",
        "NtOpenKeyEx",
        "NtOpenKeyTransacted",
        "NtOpenKeyTransactedEx",
        "NtOpenKeyedEvent",
        "NtOpenMutant",
        "NtOpenObjectAuditAlarm",
        "NtOpenPartition",
        "NtOpenPrivateNamespace",
        "NtOpenProcessToken",
        "NtOpenRegistryTransaction",
        "NtOpenResourceManager",
        "NtOpenSemaphore",
        "NtOpenSession",
        "NtOpenSymbolicLinkObject",
        "NtOpenThread",
        "NtOpenTimer",
        "NtOpenTransaction",
        "NtOpenTransactionManager",
        "NtPlugPlayControl",
        "NtPrePrepareComplete",
        "NtPrePrepareEnlistment",
        "NtPrepareComplete",
        "NtPrepareEnlistment",
        "NtPrivilegeCheck",
        "NtPrivilegeObjectAuditAlarm",
        "NtPrivilegedServiceAuditAlarm",
        "NtPropagationComplete",
        "NtPropagationFailed",
        "NtPulseEvent",
        "NtQueryBootEntryOrder",
        "NtQueryBootOptions",
        "NtQueryDebugFilterState",
        "NtQueryDirectoryObject",
        "NtQueryDriverEntryOrder",
        "NtQueryEaFile",
        "NtQueryFullAttributesFile",
        "NtQueryInformationAtom",
        "NtQueryInformationEnlistment",
        "NtQueryInformationJobObject",
        "NtQueryInformationPort",
        "NtQueryInformationResourceManager",
        "NtQueryInformationTransaction",
        "NtQueryInformationTransactionManager",
        "NtQueryInformationWorkerFactory",
        "NtQueryInstallUILanguage",
        "NtQueryIntervalProfile",
        "NtQueryIoCompletion",
        "NtQueryLicenseValue",
        "NtQueryMultipleValueKey",
        "NtQueryMutant",
        "NtQueryOpenSubKeys",
        "NtQueryOpenSubKeysEx",
        "CmpForceInvalidatePreCallback",
        "NtQueryQuotaInformationFile",
        "NtQuerySecurityAttributesToken",
        "NtQuerySecurityObject",
        "NtQuerySecurityPolicy",
        "NtQuerySemaphore",
        "NtQuerySymbolicLinkObject",
        "NtQuerySystemEnvironmentValue",
        "NtQuerySystemEnvironmentValueEx",
        "NtQuerySystemInformationEx",
        "NtQueryTimerResolution",
        "NtQueryWnfStateData",
        "NtQueryWnfStateNameInformation",
        "NtQueueApcThreadEx",
        "NtRaiseException",
        "NtRaiseHardError",
        "NtReadOnlyEnlistment",
        "NtRecoverEnlistment",
        "NtRecoverResourceManager",
        "NtRecoverTransactionManager",
        "NtRegisterProtocolAddressInformation",
        "NtRegisterThreadTerminatePort",
        "NtReleaseKeyedEvent",
        "NtReleaseWorkerFactoryWorker",
        "NtRemoveIoCompletionEx",
        "NtRemoveProcessDebug",
        "NtRenameKey",
        "NtRenameTransactionManager",
        "NtReplaceKey",
        "NtReplacePartitionUnit",
        "NtReplyWaitReplyPort",
        "NtRequestPort",
        "NtResetEvent",
        "NtResetWriteWatch",
        "NtRestoreKey",
        "NtResumeProcess",
        "NtRevertContainerImpersonation",
        "NtRollbackComplete",
        "NtRollbackEnlistment",
        "NtRollbackRegistryTransaction",
        "NtRollbackTransaction",
        "NtRollforwardTransactionManager",
        "NtSaveKey",
        "NtSaveKeyEx",
        "NtSaveMergedKeys",
        "NtSecureConnectPort",
        "NtSerializeBoot",
        "NtSetBootEntryOrder",
        "NtSetBootOptions",
        "NtSetCachedSigningLevel",
        "NtSetCachedSigningLevel2",
        "NtSetContextThread",
        "NtSetDebugFilterState",
        "NtSetDefaultHardErrorPort",
        "NtSetDefaultLocale",
        "NtSetDefaultUILanguage",
        "NtSetDriverEntryOrder",
        "NtSetEaFile",
        "NtAdjustTokenClaimsAndDeviceGroups",
        "NtAdjustTokenClaimsAndDeviceGroups",
        "NtSetIRTimer",
        "NtSetInformationDebugObject",
        "NtSetInformationEnlistment",
        "NtSetInformationJobObject",
        "NtSetInformationKey",
        "NtSetInformationResourceManager",
        "NtSetInformationSymbolicLink",
        "NtSetInformationToken",
        "NtSetInformationTransaction",
        "NtSetInformationTransactionManager",
        "NtSetInformationVirtualMemory",
        "NtSetInformationWorkerFactory",
        "NtSetIntervalProfile",
        "NtSetIoCompletion",
        "NtSetIoCompletionEx",
        "BvgaSetVirtualFrameBuffer",
        "NtAdjustTokenClaimsAndDeviceGroups",
        "NtAdjustTokenClaimsAndDeviceGroups",
        "NtSetQuotaInformationFile",
        "NtSetSecurityObject",
        "NtSetSystemEnvironmentValue",
        "NtSetSystemEnvironmentValueEx",
        "NtSetSystemInformation",
        "NtSetSystemPowerState",
        "NtSetSystemTime",
        "NtSetThreadExecutionState",
        "NtSetTimer2",
        "NtSetTimerEx",
        "NtSetTimerResolution",
        "NtSetUuidSeed",
        "NtSetVolumeInformationFile",
        "NtSetWnfProcessNotificationEvent",
        "NtShutdownSystem",
        "NtShutdownWorkerFactory",
        "NtSignalAndWaitForSingleObject",
        "NtSinglePhaseReject",
        "NtStartProfile",
        "NtStopProfile",
        "NtSubscribeWnfStateChange",
        "NtSuspendProcess",
        "NtSuspendThread",
        "NtSystemDebugControl",
        "NtTerminateJobObject",
        "NtTestAlert",
        "NtThawRegistry",
        "NtThawTransactions",
        "NtTraceControl",
        "NtTranslateFilePath",
        "NtUmsThreadYield",
        "NtUnloadDriver",
        "NtUnloadKey",
        "NtUnloadKey2",
        "NtUnloadKeyEx",
        "NtUnlockFile",
        "NtUnlockVirtualMemory",
        "NtUnmapViewOfSectionEx",
        "NtUnsubscribeWnfStateChange",
        "NtUpdateWnfStateData",
        "NtAdjustTokenClaimsAndDeviceGroups",
        "NtWaitForAlertByThreadId",
        "NtWaitForDebugEvent",
        "NtWaitForKeyedEvent",
        "NtWaitForWorkViaWorkerFactory",
        "NtAdjustTokenClaimsAndDeviceGroups",
        "NtAdjustTokenClaimsAndDeviceGroups"
    ]
]